@@ -117,6 +117,8 @@ SubCmdMetaData::SubCmdMetaData()
     _sCmds.push_back(new SubCmd("", "extract_fw_data", SC_Extract_4MB_Image));
     _sCmds.push_back(new SubCmd("", "set_public_keys", SC_Set_Public_Keys));
     _sCmds.push_back(new SubCmd("", "set_forbidden_versions", SC_Set_Forbidden_Versions));
+    _sCmds.push_back(new SubCmd("ir", "image_reactivation", SC_Image_Reactivation));
+    _sCmds.push_back(new SubCmd("bc", "binary_compare", SC_Binary_Compare));
 }
 
 SubCmdMetaData::~SubCmdMetaData()
@@ -168,6 +170,9 @@ FlagMetaData::FlagMetaData()
     _flags.push_back(new Flag("", "hh", 0));
     _flags.push_back(new Flag("i", "image", 1));
     _flags.push_back(new Flag("", "qq", 0));
+    _flags.push_back(new Flag("", "low_cpu", 0));
+    _flags.push_back(new Flag("", "next_boot_fw_ver", 0));
+    _flags.push_back(new Flag("", "flashed_version", 0));
     _flags.push_back(new Flag("", "nofs", 0));
     _flags.push_back(new Flag("", "allow_psid_change", 0));
     _flags.push_back(new Flag("", "allow_rom_change", 0));
@@ -199,6 +204,8 @@ FlagMetaData::FlagMetaData()
     _flags.push_back(new Flag("", "hmac_key", 1));
     _flags.push_back(new Flag("", "key_uuid2", 1));
     _flags.push_back(new Flag("", "no_fw_ctrl", 0));
+    _flags.push_back(new Flag("", "ir", 0));
+    _flags.push_back(new Flag("", "latest_fw", 0));
 }
 
 FlagMetaData::~FlagMetaData()
@@ -411,6 +418,16 @@ void Flint::initCmdParser()
                "Binary image file.\n"
                "Commands affected: burn, verify");
 
+    AddOptions("latest_fw",
+        ' ',
+        "",
+        "Commands affected: burn");
+
+    AddOptions("ir",
+        ' ',
+        "",
+        "Commands affected: burn");
+
     AddOptions("help",
                'h',
                "",
@@ -500,6 +517,24 @@ void Flint::initCmdParser()
                "Run a quick query. When specified, flint will not perform full image integrity checks during the query"
                " operation. This may shorten execution time when running over slow interfaces (e.g., I2C, MTUSB-1).\n"
                "Commands affected: query");
+    AddOptions("low_cpu",
+               ' ',
+               "",
+               "When specified, cpu usage will be reduced. Run time might be increased\n"
+               "Commands affected: query");
+
+    AddOptions("next_boot_fw_ver",
+               ' ',
+               "",
+               "When specified, only next boot fw version is fetched\n"
+               "Commands affected: query",
+               true);
+
+    AddOptions("flashed_version",
+               ' ',
+               "",
+               "When specified, only flashed fw version is fetched\n"
+               "Commands affected: query");
 
     AddOptions("nofs",
                ' ',
@@ -612,6 +647,8 @@ void Flint::initCmdParser()
                ' ',
                "<log_file>",
                "Print the burning status to the specified log file");
+    
+    
 
     char flashList[FLASH_LIST_SZ] = {0};
     char flashParDesc[FLASH_LIST_SZ * 2];
@@ -720,7 +757,7 @@ ParseStatus Flint::HandleOption(string name, string value)
     if (!(verifyNumOfArgs(name, value))) {
         return PARSE_ERROR;
     }
-
+    int delta = 1;
     if (name == "device" || name == "d") {
         _flintParams.device_specified = true;
         _flintParams.device = value;
@@ -809,6 +846,11 @@ ParseStatus Flint::HandleOption(string name, string value)
     } else if (name == "qq") {
         _flintParams.quick_query = true;
         _flintParams.skip_rom_query = true;
+        delta = 2;
+    } else if (name == "low_cpu") {
+        _flintParams.low_cpu = true;
+    } else if (name == "next_boot_fw_ver" || name == "flashed_version") {
+        _flintParams.next_boot_fw_ver = true;
     } else if (name == "nofs") {
         _flintParams.nofs = true;
     } else if (name == "allow_psid_change") {
@@ -848,7 +890,10 @@ ParseStatus Flint::HandleOption(string name, string value)
         _flintParams.striped_image = true;
     } else if (name == "use_dev_img_info") {
         _flintParams.use_dev_img_info = true;
-    } else if (name == "banks") {
+    } else if (name == "ir") {
+        _flintParams.image_reactivation = true;
+    }
+    else if (name == "banks") {
         _flintParams.banks_specified = true;
         u_int64_t banksNum;
         if (!strToNum(value, banksNum)) {
@@ -879,11 +924,15 @@ ParseStatus Flint::HandleOption(string name, string value)
     } else if (name == "key_uuid2") {
         _flintParams.uuid2_specified = true;
         _flintParams.privkey2_uuid = value;
-    } else {
+    } else if (name == "latest_fw") {
+        _flintParams.use_latest_fw_version = true;
+    }
+    else {
         cout << "Unknown Flag: " << name;
         cout << _cmdParser.GetSynopsis();
         return PARSE_ERROR;
     }
+    _flintParams.num_of_args += delta;
     return PARSE_OK;
 }
 
