@@ -2,7 +2,7 @@
  *
  * flint_params.cpp - FLash INTerface
  *
- * Copyright (C) Jan 2013 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2013 Mellanox Technologies Ltd.  All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -48,16 +48,20 @@ FlintParams::FlintParams()
     mac_specified = false;
     macs_specified = false;
     uid_specified = false;
-    uids_specified = false;
     device_specified = false;
     blank_guids = false;
     clear_semaphore = false;
     quick_query = true;  //should now be true by default
+    next_boot_fw_ver = false;
+    low_cpu = false;
+    skip_rom_query = false;
     image_specified = false;
+    mfa2_specified = false;
     nofs = false;
     allow_psid_change = false;
     allow_rom_change = false;
     override_cache_replacement = false;
+    use_fw = false; // access flash via FW on CX3/CX3Pro
     no_flash_verify = false;
     silent = false;
     yes = false;
@@ -68,8 +72,9 @@ FlintParams::FlintParams()
     use_image_rom = false;
     dual_image = false;
     striped_image = false;
+    ignore_dev_data = false;
     banks_specified = false;
-    banks = 4;
+    banks = -1; // must be -1 for mflash to get default num of flash
     log_specified = false;
     flash_params_specified = false;
     flash_params.type_name = (char*)NULL;
@@ -79,6 +84,18 @@ FlintParams::FlintParams()
     baseUid.l = 0;
     flash_params.num_of_flashes = 0;
     flash_params.log2size = 0;
+    use_dev_img_info = false;
+    skip_ci_req = false;
+    use_dev_rom = false;
+    privkey_specified = false;
+    privkey2_specified = false;
+    uuid_specified = false;
+    uuid2_specified = false;
+    no_fw_ctrl = false;
+    image_reactivation = false;
+    num_of_args = 0;
+    use_latest_fw_version = false;
+
 }
 
 FlintParams::~FlintParams()
