@@ -84,9 +84,11 @@ typedef enum {
     SC_Add_Hmac,
     SC_Extract_4MB_Image,
     SC_Set_Public_Keys,
-    SC_Set_Forbidden_Versions
+    SC_Set_Forbidden_Versions,
+    SC_Image_Reactivation,
+    SC_Binary_Compare
 } sub_cmd_t;
-
+ 
 class FlintParams {
 public:
     //add more params
@@ -108,8 +110,11 @@ public:
     bool blank_guids;
     bool clear_semaphore;
     bool quick_query;
+    bool low_cpu;
+    bool next_boot_fw_ver;
     bool skip_rom_query;
     bool image_specified;
+    bool mfa2_specified;
     string image;
     bool nofs;
     bool allow_psid_change;
@@ -142,7 +147,9 @@ public:
     bool skip_ci_req;
     bool use_dev_rom;
     bool privkey_specified;
+    bool pubkey_specified;
     string privkey_file;
+    string pubkey_file;
     bool uuid_specified;
     string privkey_uuid;
     bool privkey2_specified;
@@ -152,6 +159,9 @@ public:
     bool uuid2_specified;
     string privkey2_uuid;
     bool no_fw_ctrl;
+    bool image_reactivation;
+    int num_of_args;
+    bool use_latest_fw_version;
 };
 
 #endif
