@@ -38,12 +38,11 @@
  */
 
 #include "fw_comps_mgr.h"
-#include "compatibility.h"
+#include "fw_comps_mgr_abstract_access.h"
 #include "bit_slice.h"
-#include <time.h>
-#include <stdlib.h>
 #include <signal.h>
 
+#include "mflash/mflash_access_layer.h"
 #ifndef UEFI_BUILD
 #include <mft_sig_handler.h>
 #include "mad_ifc/mad_ifc.h"
@@ -57,11 +56,9 @@ static void mft_signal_set_handling(int isOn)
 
 #define DEFAULT_SIZE 64
 #define MAX_TOUT 1000
+#define REG_ACCESS_TOUT 100
 #define SLEEP_TIME 80
 #define INIT_PARTITION_SLEEP_TIME 240
-#define MAX_MSG_SIZE 128
-
-#define MAX_REG_DATA 128
 
 #define MTCR_IB_TIMEOUT_VAR "MTCR_IB_TIMEOUT"
 #define MTCR_IB_TIMEOUT_VAL "30000"
@@ -76,7 +73,14 @@ static void mft_signal_set_handling(int isOn)
 #define IS4_DEVID       0x1b3
 
 
-typedef struct reg_access_hca_mcda_reg mcdaReg;
+#ifndef UEFI_BUILD
+#define DPRINTF(args)        do { char *reacDebug = getenv("FW_COMPS_DEBUG"); \
+                                  if (reacDebug != NULL) { \
+                                      printf("[FW_COMPS_DEBUG]: -D- "); printf args;} } while (0)
+#else
+#define DPRINTF(...)
+#endif
+
 /*
  * Wrapper to call the MCDA command
  */
@@ -95,7 +99,7 @@ bool FwCompsMgr::runNVDA(std::vector<u_int8_t>& buff,
         nvdaTlv.nv_hdr.default_ = 1;
     }
     // tlvType should be in the correct endianess
-    nvdaTlv.nv_hdr.type.tlv_type_dw.tlv_type_dw =  tlvType;
+    nvdaTlv.nv_hdr.type.tlv_type_dw.tlv_type_dw = tlvType;
     if (method == REG_ACCESS_METHOD_SET) {
         memcpy(nvdaTlv.data, buff.data(), len);
     }
@@ -106,6 +110,7 @@ bool FwCompsMgr::runNVDA(std::vector<u_int8_t>& buff,
     deal_with_signal();
     if (rc) {
         _lastError = regErrTrans(rc);
+        setLastRegisterAccessStatus(rc);
         return false;
     }
     if (buff.size() < nvdaTlv.nv_hdr.length) {
@@ -116,89 +121,15 @@ bool FwCompsMgr::runNVDA(std::vector<u_int8_t>& buff,
 }
 
 bool FwCompsMgr::accessComponent(u_int32_t offset,
-                                 u_int32_t size,
-                                 u_int32_t data[],
-                                 access_type_t access,
-                                 ProgressCallBackAdvSt *progressFuncAdv)
+    u_int32_t size,
+    u_int32_t data[],
+    access_type_t access,
+    ProgressCallBackAdvSt *progressFuncAdv)
 {
-    int leftSize = (int)size;
-    u_int32_t i = 0;
-    mcdaReg accessData;
-    char stage[MAX_MSG_SIZE] = {0};
-    int progressPercentage = -1;
-    if (progressFuncAdv && progressFuncAdv->func) {
-        snprintf(stage, MAX_MSG_SIZE, "%s %s component", (access == MCDA_READ_COMP) ? "Reading" : "Writing", _currComponentStr);
-    }
-    int maxDataSize = mget_max_reg_size(_mf, (access == MCDA_READ_COMP) ? MACCESS_REG_METHOD_GET : MACCESS_REG_METHOD_SET)
-        - sizeof(accessData);
-    if (maxDataSize > MAX_REG_DATA) {
-        maxDataSize = MAX_REG_DATA;
-    }
-    std::vector<u_int32_t> dataToRW(maxDataSize, 0);
-    while (leftSize > 0) {
-        memset(&accessData, 0, sizeof(mcdaReg));
-        accessData.data = dataToRW.data();
-        accessData.update_handle = _updateHandle;
-        accessData.offset = offset + (size - leftSize);
-        accessData.size   = leftSize > maxDataSize ? maxDataSize : leftSize;
-        mft_signal_set_handling(1);
-
-        if (access == MCDA_READ_COMP) {
-            reg_access_status_t rc = reg_access_mcda(_mf, REG_ACCESS_METHOD_GET, &accessData);
-            deal_with_signal();
-            if (rc) {
-                _lastError = regErrTrans(rc);
-                return false;
-            }
-            for (i = 0; i < accessData.size / 4; i++) {
-                data[(size - leftSize) / 4 + i] = ___my_swab32(accessData.data[i]);
-            }
-            //printf("data[%#02x]: %#08x\n", (i-1)*4, data[(size - leftSize)/4 + i-1]);
-        } else {
-            for (i = 0; i < accessData.size / 4; i++) {
-                accessData.data[i] = ___my_swab32(data[(size - leftSize) / 4 + i]);
-            }
-            reg_access_status_t rc = reg_access_mcda(_mf, REG_ACCESS_METHOD_SET, &accessData);
-            deal_with_signal();
-            if (rc) {
-                _lastError = regErrTrans(rc);
-                return false;
-            }
-        }
-        int newPercentage = (((size - leftSize) * 100) / size);
-        if (newPercentage > progressPercentage &&
-            progressFuncAdv && progressFuncAdv->func) {
-            progressPercentage = newPercentage;
-            if (progressFuncAdv->func(progressPercentage, stage,
-                                      PROG_WITH_PRECENTAGE, progressFuncAdv->opaque)) {
-                _lastError = FWCOMPS_ABORTED;
-                return false;
-            }
-        }
-        leftSize -= maxDataSize;
-    }
-    if (progressFuncAdv && progressFuncAdv->func) {
-        if (progressFuncAdv->func(0, stage,
-                                  PROG_OK, progressFuncAdv->opaque)) {
-            _lastError = FWCOMPS_ABORTED;
-            return false;
-        }
-    }
-    return true;
-}
-
-bool FwCompsMgr::queryComponentStaus(u_int32_t componentIndex,
-                                     comp_status_st *query)
-{
-    mft_signal_set_handling(1);
-    query->component_index = componentIndex;
-    reg_access_status_t rc = reg_access_mcqs(_mf, REG_ACCESS_METHOD_GET, query);
-    deal_with_signal();
-    if (rc) {
-        _lastError = regErrTrans(rc);
-        return false;
-    }
-    return true;
+    bool bRes = _accessObj->accessComponent(_updateHandle, offset, size, data, access, _currComponentStr, progressFuncAdv);
+    setLastFirmwareError(_accessObj->getLastFirmwareError());
+    setLastRegisterAccessStatus(_accessObj->getLastRegisterAccessStatus());
+    return bRes;
 }
 
 const char* FwCompsMgr::stateToStr(fsm_state_t st)
@@ -230,33 +161,42 @@ bool FwCompsMgr::controlFsm(fsm_command_t command,
                             fsm_state_t expStatus,
                             u_int32_t size,
                             fsm_state_t currState,
-                            ProgressCallBackAdvSt *progressFuncAdv)
+                            ProgressCallBackAdvSt *progressFuncAdv,
+                            u_int32_t reg_access_timeout)
 {
     reg_access_status_t rc = ME_OK;
-    int count = 0;
+    reg_access_method_t method = REG_ACCESS_METHOD_SET;
+    if (!reg_access_timeout) {
+        reg_access_timeout = MAX_TOUT;
+    }
+    unsigned int count = 0;
     do {
         if (count) {
             msleep(SLEEP_TIME);
         }
-        reg_access_method_t method = REG_ACCESS_METHOD_SET;
+        method = REG_ACCESS_METHOD_SET;
         if (command == FSM_QUERY) {
             method = REG_ACCESS_METHOD_GET;
         }
         mft_signal_set_handling(1);
         memset(&_lastFsmCtrl, 0, sizeof(_lastFsmCtrl));
         _lastFsmCtrl.instruction = command;
+        _lastFsmCtrl.device_index = _deviceIndex;
+        _lastFsmCtrl.device_type = _deviceType;
         _lastFsmCtrl.component_index = _componentIndex;
         _lastFsmCtrl.component_size = size;
         _lastFsmCtrl.update_handle = _updateHandle;
         rc = reg_access_mcc(_mf, method, &_lastFsmCtrl);
 
         deal_with_signal();
-    } while (rc == ME_REG_ACCESS_RES_NOT_AVLBL && count++ < MAX_TOUT);
+    } while (rc == ME_REG_ACCESS_RES_NOT_AVLBL && count++ < reg_access_timeout);
     if (rc) {
         if (_lastFsmCtrl.error_code) {
             _lastError = mccErrTrans(_lastFsmCtrl.error_code);
-        } else {
+        }
+        else {
             _lastError = regErrTrans(rc);
+            setLastRegisterAccessStatus(rc);
         }
         return false;
     }
@@ -316,15 +256,18 @@ bool FwCompsMgr::runMCQI(u_int32_t componentIndex,
     _currCompInfo.offset = offset;
     _currCompInfo.data_size = dataSize;
     _currCompInfo.component_index = componentIndex;
+    _currCompInfo.device_index = _deviceIndex;
+    _currCompInfo.device_type = _deviceType;
 
     if (dataSize) {
         dataInfo.resize(dataSize, 0);
-        _currCompInfo.data =  dataInfo.data();
+        _currCompInfo.data = dataInfo.data();
     }
     reg_access_status_t rc = reg_access_mcqi(_mf, REG_ACCESS_METHOD_GET, &_currCompInfo);
     deal_with_signal();
     if (rc) {
         _lastError = regErrTrans(rc);
+        setLastRegisterAccessStatus(rc);
         ret = false;
         goto cleanup;
     }
@@ -340,7 +283,7 @@ cleanup:
     return ret;
 }
 
-bool FwCompsMgr::getDeviceHWInfo(FwCompsMgr::deviceDescription op, vector<u_int8_t>& infoString)
+bool FwCompsMgr::getDeviceHWInfo(FwCompsMgr::MQISDeviceDescriptionT op, vector<u_int8_t>& infoString)
 {
     mqisReg mqisRegister;
     mfile *mf;
@@ -349,39 +292,36 @@ bool FwCompsMgr::getDeviceHWInfo(FwCompsMgr::deviceDescription op, vector<u_int8
         return false;
     }
     reg_access_status_t rc;
-    int maxDataSize = mget_max_reg_size(mf, MACCESS_REG_METHOD_GET) - sizeof(mqisRegister);
-    if (maxDataSize > MAX_REG_DATA) {
-        maxDataSize = sizeof(mqisRegister);
-    }
-    std::vector<u_int32_t> dataVector(maxDataSize / 4, 0);
+    int maxDataSize = sizeof(mqisRegister.info_string);
 
     memset(&mqisRegister, 0, sizeof(mqisReg));
-    if (op == DEVICE_NAME) {
-        mqisRegister.info_type = 0x1;
-    } else if (op == DEVICE_DESCRIPTION_INFO) {
-        mqisRegister.info_type = 0x2;
-    }
+    if (op < MQIS_REGISTER_FIRST_VALUE || op > MQIS_REGISTER_LAST_VALUE)
+        return false;
+
+    mqisRegister.info_type = (u_int8_t)op;
     mqisRegister.read_length = maxDataSize;
-    mqisRegister.info_string = dataVector.data();
     mft_signal_set_handling(1);
 
     rc = reg_access_mqis(mf, REG_ACCESS_METHOD_GET, &mqisRegister);
     deal_with_signal();
     if (rc) {
-       return false;
+        return false;
     }
     int infoSize = mqisRegister.info_length;
     if (infoSize == 0) {
         return false;
     }
-    infoString.resize(infoSize + 1, 0);
-    if (mqisRegister.info_length > maxDataSize) {
-        dataVector.resize((infoSize + 3) / 4);
-        int leftSize = infoSize - maxDataSize;
+    infoString.resize(infoSize + 1, '\0');
+
+    // copy the output
+    memcpy(infoString.data(), mqisRegister.info_string,
+            mqisRegister.read_length);
+
+    if (infoSize > mqisRegister.read_length) {
+        int leftSize = infoSize - mqisRegister.read_length;
         while (leftSize > 0) {
             mqisRegister.read_offset = infoSize - leftSize;
             mqisRegister.read_length = leftSize > maxDataSize ? maxDataSize : leftSize;
-            mqisRegister.info_string = dataVector.data() + (mqisRegister.read_offset / 4);
             mft_signal_set_handling(1);
 
             rc = reg_access_mqis(mf, REG_ACCESS_METHOD_GET, &mqisRegister);
@@ -389,11 +329,11 @@ bool FwCompsMgr::getDeviceHWInfo(FwCompsMgr::deviceDescription op, vector<u_int8
             if (rc) {
                 return false;
             }
-            leftSize = leftSize - maxDataSize;
+            memcpy(infoString.data() + mqisRegister.read_offset,
+                   (mqisRegister.info_string), mqisRegister.read_length);
+            leftSize -= mqisRegister.read_length;
         }
     }
-
-    memcpy(infoString.data(), dataVector.data(), infoSize);
     return true;
 }
 
@@ -428,7 +368,7 @@ bool FwCompsMgr::queryComponentInfo(u_int32_t componentIndex,
     return true;
 }
 
-reg_access_status_t FwCompsMgr::getGI(mfile *mf, struct tools_open_mgir *gi)
+reg_access_status_t FwCompsMgr::getGI(mfile *mf, mgirReg *gi)
 {
     reg_access_status_t rc = ME_REG_ACCESS_OK;
     u_int32_t tp = 0;
@@ -445,7 +385,8 @@ reg_access_status_t FwCompsMgr::getGI(mfile *mf, struct tools_open_mgir *gi)
             goto cleanup;
         }
         rc = (reg_access_status_t)mad_ifc_general_info_sw(mf, &gi->sw_info);
-    } else {
+    }
+    else {
         rc = reg_access_mgir(mf, REG_ACCESS_METHOD_GET, gi);
         goto cleanup;
     }
@@ -486,22 +427,34 @@ void FwCompsMgr::initialize(mfile *mf)
     if (getFwSupport()) {
         generateHandle();
     }
+    ComponentAccessFactory* factory = ComponentAccessFactory::GetInstance();
+    _accessObj = factory->createDataAccessObject(this, mf, isDmaSupported);
     _refreshed = false;
 }
 
-FwCompsMgr::FwCompsMgr(mfile *mf)
+FwCompsMgr::FwCompsMgr(mfile *mf, DeviceTypeT devType, int deviceIndex)
 {
     _clearSetEnv = false;
     _openedMfile = false;
     _hwDevId = 0;
+    _deviceType = devType;
+    _deviceIndex = deviceIndex;
+    _accessObj = NULL;
+    _mircCaps = false;
+#ifndef UEFI_BUILD    
+    _trm = NULL;
+#endif    
     initialize(mf);
 }
 
-FwCompsMgr::FwCompsMgr(const char *devname)
+FwCompsMgr::FwCompsMgr(const char *devname, DeviceTypeT devType, int deviceIndex)
 {
     _mf = NULL;
     _openedMfile = false;
     _clearSetEnv = false;
+    _accessObj = NULL;
+    _deviceType = devType;
+    _deviceIndex = deviceIndex;
 #ifndef UEFI_BUILD
     if (getenv(MTCR_IB_TIMEOUT_VAR) == NULL) {
         _clearSetEnv = true;
@@ -513,6 +466,10 @@ FwCompsMgr::FwCompsMgr(const char *devname)
     }
 #endif
     _hwDevId = 0;
+    _mircCaps = false;
+#ifndef UEFI_BUILD    
+    _trm = NULL;
+#endif    
     _lastError = FWCOMPS_SUCCESS;
     mfile *mf = mopen(devname);
     if (!mf) {
@@ -526,17 +483,18 @@ FwCompsMgr::FwCompsMgr(const char *devname)
 FwCompsMgr::FwCompsMgr(uefi_Dev_t *uefi_dev, uefi_dev_extra_t *uefi_extra)
 {
     _mf = NULL;
+    _accessObj = NULL;
     _openedMfile = false;
     _clearSetEnv = false;
-
+    _mircCaps = false;
     mfile *mf = mopen_fw_ctx((void *)uefi_dev, (void *)uefi_extra->fw_cmd_func, \
-                             (void *)uefi_extra->dev_info);
+        (void *)&uefi_extra->dev_info);
     if (!mf) {
         _lastError = FWCOMPS_MEM_ALLOC_FAILED;
         return;
     }
-    if (uefi_extra->dev_info != NULL) {
-        _hwDevId = uefi_extra->dev_info->hw_dev_id;
+    if (&uefi_extra->dev_info != NULL) {
+        _hwDevId = uefi_extra->dev_info.hw_dev_id;
     }
     _openedMfile = true;
     initialize(mf);
@@ -562,6 +520,10 @@ FwCompsMgr::~FwCompsMgr()
             mclose(_mf);
         }
     }
+    if (_accessObj != NULL) {
+        delete _accessObj;
+        _accessObj = NULL;
+    }
 }
 
 bool FwCompsMgr::forceRelease()
@@ -571,7 +533,7 @@ bool FwCompsMgr::forceRelease()
 
 void FwCompsMgr::generateHandle()
 {
-    if (!controlFsm(FSM_QUERY)) {
+    if (!controlFsm(FSM_QUERY, FSMST_NA, 0, FSMST_NA, NULL, REG_ACCESS_TOUT)) {
         _updateHandle = 0;
         return;
     }
@@ -592,10 +554,10 @@ bool FwCompsMgr::refreshComponentsStatus()
     _compsQueryMap.resize((unsigned)(FwComponent::COMPID_UNKNOWN));
     while (!last_index_flag) {
         memset(&compStatus, 0, sizeof(comp_query_st));
-        if (queryComponentStaus(compIdx, &(compStatus.comp_status))) {
+        if (queryComponentStatus(compIdx, &(compStatus.comp_status))) {
             compStatus.comp_status.component_index = compIdx;
             /* */
-            u_int32_t capSt[DEFAULT_SIZE] = {0};
+            u_int32_t capSt[DEFAULT_SIZE] = { 0 };
             if (queryComponentInfo(_componentIndex, 1, COMPINFO_CAPABILITIES, DEFAULT_SIZE, capSt) == false) {
                 if (queryComponentInfo(_componentIndex, 0, COMPINFO_CAPABILITIES, DEFAULT_SIZE, capSt) == false) {
                     //_lastError = FWCOMPS_REG_FAILED;
@@ -608,8 +570,9 @@ bool FwCompsMgr::refreshComponentsStatus()
             memcpy(&(_compsQueryMap[compStatus.comp_status.identifier]), &compStatus, sizeof(compStatus));
             //printf("-D- Found component: %#x\n", compStatus.comp_status.identifier);
             last_index_flag = compStatus.comp_status.last_index_flag;
-        } else {
-            //printf("-D- queryComponentStaus failed !!\n");
+        }
+        else {
+            //printf("-D- queryComponentStatus failed !!\n");
             return false;
         }
         compIdx++;
@@ -647,7 +610,8 @@ bool FwCompsMgr::readComponent(FwComponent::comps_ids_t compType, FwComponent& f
         if (!controlFsm(FSM_CMD_RELEASE_UPDATE_HANDLE)) {
             return false;
         }
-    } else {
+    }
+    else {
         _lastError = FWCOMPS_READ_COMP_NOT_SUPPORTED;
         return false;
     }
@@ -675,12 +639,29 @@ bool FwCompsMgr::readComponentInfo(FwComponent::comps_ids_t compType,
         retData.resize(size);
         queryComponentInfo(_componentIndex, readPending == true, infoType, size, (u_int32_t *)(retData.data()));
         return true;
-    } else {
+    }
+    else {
         _lastError = FWCOMPS_INFO_TYPE_NOT_SUPPORTED;
         return false;
     }
 }
 
+bool FwCompsMgr::queryComponentStatus(u_int32_t componentIndex,
+    comp_status_st *query)
+{
+    mft_signal_set_handling(1);
+    query->component_index = componentIndex;
+    query->device_index = _deviceIndex;
+    query->device_type = _deviceType;
+    reg_access_status_t rc = reg_access_mcqs(_mf, REG_ACCESS_METHOD_GET, query);
+    deal_with_signal();
+    if (rc) {
+        _lastError = regErrTrans(rc);
+        setLastRegisterAccessStatus(rc);
+        return false;
+    }
+    return true;
+}
 
 bool FwCompsMgr::burnComponents(std::vector<FwComponent>& comps,
                                 ProgressCallBackAdvSt *progressFuncAdv)
@@ -690,6 +671,7 @@ bool FwCompsMgr::burnComponents(std::vector<FwComponent>& comps,
         return false;
     }
     if (!controlFsm(FSM_CMD_LOCK_UPDATE_HANDLE, FSMST_LOCKED)) {
+        forceRelease();
         return false;
     }
     for (i = 0; i < comps.size(); i++) {
@@ -708,6 +690,7 @@ bool FwCompsMgr::burnComponents(std::vector<FwComponent>& comps,
             return false;
         }
         if (!controlFsm(FSM_CMD_VERIFY_COMPONENT, FSMST_LOCKED, 0, FSMST_NA, progressFuncAdv)) {
+            DPRINTF(("Verifying component has failed!\n"));
             return false;
         }
     }
@@ -728,7 +711,7 @@ bool FwCompsMgr::getFwComponents(std::vector<FwComponent>& compsMap, bool readEn
         return false;
     }
     for (std::vector<comp_query_st>::iterator it = _compsQueryMap.begin();
-         it != _compsQueryMap.end(); it++) {
+        it != _compsQueryMap.end(); it++) {
         if (!it->valid) {
             continue;
         }
@@ -736,7 +719,8 @@ bool FwCompsMgr::getFwComponents(std::vector<FwComponent>& compsMap, bool readEn
                           (FwComponent::comps_status_t)it->comp_status.component_status);
         if (readEn && !readComponent((FwComponent::comps_ids_t)it->comp_status.identifier, fwCmp, 0)) {
             return false;
-        } else {
+        }
+        else {
             fwCmp.setSize(it->comp_cap.component_size);
         }
         compsMap.push_back(fwCmp);
@@ -772,7 +756,7 @@ const char* FwComponent::getCompIdStr(comps_ids_t compId)
         break;
 
     default:
-        return "UNKNOW_COMPONENT";
+        return "UNKNOWN_COMPONENT";
         break;
     }
 }
@@ -782,7 +766,6 @@ void FwCompsMgr::getInfoAsVersion(std::vector<u_int32_t>& infoData,
 {
     u_int8_t *data = (u_int8_t *)(infoData.data());
     reg_access_hca_mcqi_version_unpack(cmpVer, data);
-    cmpVer->version_string = (u_int32_t *)(data + reg_access_hca_mcqi_version_size());
     //reg_access_hca_mcqi_version_print(cmpVer, stdout, 4);
 }
 
@@ -790,6 +773,8 @@ void FwCompsMgr::getInfoAsVersion(std::vector<u_int32_t>& infoData,
 u_int32_t FwCompsMgr::getFwSupport()
 {
     u_int32_t devid = 0;
+    isDmaSupported = false;
+
 #ifndef UEFI_BUILD
     if (getenv("FW_CTRL") != NULL) {
         return 1;
@@ -824,11 +809,24 @@ u_int32_t FwCompsMgr::getFwSupport()
     }
     /*
      * MCDA bit are in offsets 0x60-0x64
+     * MCDD in bit 0x5C
      * MGIR in bit 0x20
      * The bytes are in reverse order
      */
     u_int8_t mcdaCaps = EXTRACT(mcam.mng_access_reg_cap_mask[3], 0, 5);
+    u_int8_t mcddCaps = EXTRACT(mcam.mng_access_reg_cap_mask[4], 4, 1);//##EDDY: need check ! register 5c
     u_int8_t mgirCaps = EXTRACT(mcam.mng_access_reg_cap_mask[11], 0, 1);
+    if (mcddCaps == 1)
+        isDmaSupported = true;
+    memset(&mcam, 0, sizeof(mcam));
+    mcam.access_reg_group = 2;//for MIRC register
+    rc = reg_access_mcam(_mf, REG_ACCESS_METHOD_GET, &mcam);
+    if (rc) {
+        _lastError = FWCOMPS_UNSUPPORTED_DEVICE;
+        return 0;
+    }
+    _mircCaps = EXTRACT(mcam.mng_access_reg_cap_mask[3], 2, 1);//MIRC is 0x9162
+    DPRINTF(("getFwSupport _mircCaps = %d\n", _mircCaps));
     if (mcdaCaps == 0x1f && mgirCaps) {
         return 1;
     }
@@ -903,21 +901,24 @@ bool FwCompsMgr::setMacsGuids(mac_guid_t macGuid)
 u_int8_t transRomType(u_int8_t mgirRomType)
 {
     switch (mgirRomType) {
-    case 0x1:
+    case 0x1: //FLEXBOOT
         return 0x10;
 
-    case 0x2:
+    case 0x2: //UEFI
         return 0x11;
 
-    case 0x3:
+    case 0x3: //UEFI_CLP
         return 0x12;
 
+    case 0x4: //NVMe
+        return 0x13;
+
     default:
         return mgirRomType;
     }
 }
 
-void FwCompsMgr::extractRomInfo(tools_open_mgir *mgir, fwInfoT *fwQuery)
+void FwCompsMgr::extractRomInfo(mgirReg *mgir, fwInfoT *fwQuery)
 {
     if (!fwQuery || !mgir) {
         return;
@@ -949,7 +950,7 @@ void FwCompsMgr::extractRomInfo(tools_open_mgir *mgir, fwInfoT *fwQuery)
     }
 }
 
-bool FwCompsMgr::queryFwInfo(fwInfoT *query)
+bool FwCompsMgr::queryFwInfo(fwInfoT *query, bool next_boot_fw_ver)
 {
     if (!query) {
         _lastError = FWCOMPS_BAD_PARAM;
@@ -962,6 +963,10 @@ bool FwCompsMgr::queryFwInfo(fwInfoT *query)
     if (!getComponentVersion(FwComponent::COMPID_BOOT_IMG, false, &query->running_fw_version)) {
         return false;
     }
+    if (next_boot_fw_ver) {
+        // query next_boot_fw_ver only. enough to query pending & running versions.
+        return true;
+    }
 
     if (query->running_fw_version.version_string_length &&
         query->running_fw_version.version_string_length <= PRODUCT_VER_LEN) {
@@ -972,7 +977,7 @@ bool FwCompsMgr::queryFwInfo(fwInfoT *query)
      * MGIR
      */
     reg_access_status_t rc;
-    struct tools_open_mgir mgir;
+    mgirReg mgir;
     memset(&mgir, 0, sizeof(mgir));
     rc = getGI(_mf, &mgir);
     if (rc) {
@@ -984,10 +989,10 @@ bool FwCompsMgr::queryFwInfo(fwInfoT *query)
     query->hw_dev_id = mgir.hw_info.hw_dev_id;
     query->dev_id = mgir.hw_info.device_id;
     query->rev_id = mgir.hw_info.device_hw_revision;
-    query->security_type.secure_fw = mgir.fw_info.secure_fw;
+    query->security_type.secure_fw = mgir.fw_info.secured;
     query->security_type.signed_fw = mgir.fw_info.signed_fw;
-    query->security_type.debug_fw  = mgir.fw_info.debug_fw;
-    query->security_type.dev_fw    = mgir.fw_info.dev_fw;
+    query->security_type.debug_fw = mgir.fw_info.debug;
+    query->security_type.dev_fw = mgir.fw_info.dev;
     query->signed_fw = _compsQueryMap[FwComponent::COMPID_BOOT_IMG].comp_cap.signed_updates_only;
 
     query->base_mac_orig.uid = ((u_int64_t)mgir.hw_info.manufacturing_base_mac_47_32 << 32 | mgir.hw_info.manufacturing_base_mac_31_0);
@@ -1004,11 +1009,19 @@ bool FwCompsMgr::queryFwInfo(fwInfoT *query)
      */
     vector<u_int8_t> nameInfoString;
     vector<u_int8_t> descriptionInfoString;
-    if (getDeviceHWInfo(FwCompsMgr::DEVICE_NAME, nameInfoString)) {
-        strncpy(query->name, (char *)nameInfoString.data(), NAME_LEN-1);
+    vector<u_int8_t> imageVsd;
+    vector<u_int8_t> deviceVsd;
+    if (getDeviceHWInfo(FwCompsMgr::MQIS_REGISTER_DEVICE_NAME, nameInfoString)) {
+        strncpy(query->name, (char *)nameInfoString.data(), NAME_LEN - 1);
     }
-    if (getDeviceHWInfo(FwCompsMgr::DEVICE_DESCRIPTION_INFO, descriptionInfoString)) {
-        strncpy(query->description, (char *)descriptionInfoString.data(), DESCRIPTION_LEN-1);
+    if (getDeviceHWInfo(FwCompsMgr::MQIS_REGISTER_DEVICE_DESCRIPTION_INFO, descriptionInfoString)) {
+        strncpy(query->description, (char *)descriptionInfoString.data(), DESCRIPTION_LEN - 1);
+    }
+    if (getDeviceHWInfo(FwCompsMgr::MQIS_REGISTER_IMAGE_VSD, imageVsd)) {
+        strncpy(query->imageVsd, (char *)imageVsd.data(), VSD_LEN);
+    }
+    if (getDeviceHWInfo(FwCompsMgr::MQIS_REGISTER_DEVICE_VSD, deviceVsd)) {
+        strncpy(query->deviceVsd, (char *)deviceVsd.data(), VSD_LEN);
     }
 
     return true;
@@ -1019,31 +1032,24 @@ const char*  FwCompsMgr::getLastErrMsg()
     switch (_lastError) {
     case FWCOMPS_ABORTED:
         return "Aborting ... received interrupt signal";
-        break;
 
     case FWCOMPS_MCC_ERR_REJECTED_DIGEST_ERR:
         return "The Digest in the signature is wrong";
-        break;
 
     case FWCOMPS_MCC_ERR_REJECTED_UNSIGNED:
         return "The component is not signed";
-        break;
 
     case FWCOMPS_MCC_ERR_BLOCKED_PENDING_RESET:
         return "The firmware image was already updated on flash, pending reset.";
-        break;
 
     case FWCOMPS_MCC_ERR_REJECTED_NOT_APPLICABLE:
         return "Component is not applicable";
-        break;
 
     case FWCOMPS_MCC_ERR_REJECTED_AUTH_FAILED:
         return "Rejected authentication";
-        break;
 
     case FWCOMPS_MCC_ERR_REJECTED_KEY_NOT_APPLICABLE:
         return "The key is not applicable";
-        break;
 
     case FWCOMPS_READ_COMP_NOT_SUPPORTED:
         return "Reading component is not supported";
@@ -1051,59 +1057,55 @@ const char*  FwCompsMgr::getLastErrMsg()
 
     case FWCOMPS_COMP_NOT_SUPPORTED:
         return "Component not supported";
-        break;
+
+    case FWCOMPS_VERIFY_FAILED:
+        return "Firmware verifying failed!";
 
     case FWCOMPS_CR_ERR:
         return "Failed to access CR-Space";
-        break;
 
     case FWCOMPS_MCC_REJECTED_NOT_A_SECURED_FW:
         return "The firmware image is not secured";
-        break;
 
     case FWCOMPS_MCC_REJECTED_MFG_BASE_MAC_NOT_LISTED:
         return "The manufacturing base MAC was not listed";
-        break;
 
     case FWCOMPS_MCC_REJECTED_NO_DEBUG_TOKEN:
         return "There is no Debug Token installed";
-        break;
 
     case FWCOMPS_MCC_REJECTED_VERSION_NUM_MISMATCH:
         return "Firmware version mismatch";
-        break;
 
     case FWCOMPS_MCC_REJECTED_USER_TIMESTAMP_MISMATCH:
         return "User timestamp mismatch";
-        break;
 
     case FWCOMPS_MCC_REJECTED_FORBIDDEN_VERSION:
         return "Forbidden version rejected";
-        break;
 
     case FWCOMPS_MCC_FLASH_ERASE_ERROR:
         return "Error while erasing the flash";
-        break;
 
     case FWCOMPS_MCC_UNEXPECTED_STATE:
         return "Unexpected state";
-        break;
 
     case FWCOMPS_MCC_TOUT:
         return "Time-out reached while waiting for the FSM to be updated";
-        break;
 
     case FWCOMPS_MCC_REJECTED_IMAGE_CAN_NOT_BOOT_FROM_PARTITION:
         return "Image cannot boot from partition.";
-        break;
 
     case FWCOMPS_UNSUPPORTED_DEVICE:
         return "Unsupported device";
-        break;
 
     case FWCOMPS_MTCR_OPEN_DEVICE_ERROR:
         return "Failed to open device";
 
+    case FWCOMPS_FAIL_TO_LOCK_FLASH_SEMAPHORE:
+        return "Failed to lock flash semaphore";
+
+    case FWCOMPS_FAIL_TO_CREATE_TRM_CONTEXT:
+        return "Failed to create TRM context";
+
     case FWCOMPS_REG_ACCESS_BAD_STATUS_ERR:
     case FWCOMPS_REG_ACCESS_BAD_METHOD:
     case FWCOMPS_REG_ACCESS_NOT_SUPPORTED:
@@ -1133,6 +1135,35 @@ const char*  FwCompsMgr::getLastErrMsg()
     }
 }
 
+bool FwCompsMgr::lock_flash_semaphore()
+{
+#ifndef UEFI_BUILD
+    int rc = 0;
+    trm_sts trm_rc = trm_create(&_trm, _mf);
+    if (trm_rc) {
+        _lastError = FWCOMPS_FAIL_TO_CREATE_TRM_CONTEXT;
+        return false;
+    }
+    rc = trm_lock(_trm, TRM_RES_FLASH_PROGRAMING, MAX_FLASH_PROG_SEM_RETRY_CNT);
+    if (rc && rc != TRM_STS_RES_NOT_SUPPORTED) {
+        _lastError = FWCOMPS_FAIL_TO_LOCK_FLASH_SEMAPHORE;
+        return false;
+    }
+#endif
+    return true;
+}
+
+void FwCompsMgr::unlock_flash_semaphore()
+{
+#ifndef UEFI_BUILD
+    if (_trm != NULL) {
+        trm_unlock(_trm, TRM_RES_FLASH_PROGRAMING);
+        trm_destroy(_trm);
+        _trm = NULL;
+    }
+#endif
+}
+
 
 void FwCompsMgr::deal_with_signal()
 {
@@ -1140,7 +1171,8 @@ void FwCompsMgr::deal_with_signal()
     int sig;
     sig = mft_signal_is_fired();
     if (sig) {
-        // reset recieved signal
+        unlock_flash_semaphore();
+        // reset received signal
         mft_signal_set_fired(0);
         // retore prev handler
         mft_signal_set_handling(0);
@@ -1169,7 +1201,7 @@ bool FwCompsMgr::getComponentVersion(FwComponent::comps_ids_t compType,
     if (cmpVer->version_string_length) {
         _productVerStr.resize(cmpVer->version_string_length);
         memcpy(_productVerStr.data(), cmpVer->version_string, cmpVer->version_string_length);
-        cmpVer->version_string = NULL;
+        cmpVer->version_string[0] = '\0';
     }
     return true;
 }
@@ -1208,16 +1240,110 @@ bool FwCompsMgr::readBlockFromComponent(FwComponent::comps_ids_t compId,
         if (!controlFsm(FSM_CMD_RELEASE_UPDATE_HANDLE)) {
             return false;
         }
-    } else {
+    }
+    else {
         _lastError = FWCOMPS_READ_COMP_NOT_SUPPORTED;
         return false;
     }
     return true;
 }
 
-fw_comps_error_t FwCompsMgr::regErrTrans(reg_access_status_t err)
+bool FwCompsMgr::fwReactivateImage()
+{
+    tools_open_mirc_reg mirc;
+    mirc.status_code = 0;
+    int currentIteration = 0;
+    int sleepTimeMs = 50;
+    int maxWaitingTime = 30000;//30 sec is enough time
+    int maxNumOfIterations = maxWaitingTime / sleepTimeMs;//600 iterations
+    if (_mircCaps == false) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FW_NOT_SUPPORTED;
+        setLastRegisterAccessStatus(ME_REG_ACCESS_NOT_SUPPORTED);
+        return false;
+    }
+    reg_access_status_t rc;
+    rc = reg_access_mirc(_mf, REG_ACCESS_METHOD_SET, &mirc);//send trigger to FW
+    deal_with_signal();
+    if (rc) {
+        DPRINTF(("1 reg_access_mirc failed rc = %d\n", rc));
+        _lastError = regErrTrans(rc);
+        setLastRegisterAccessStatus(rc);
+        return false;
+    }
+    else {
+        memset(&mirc, 0, sizeof(mirc));
+        msleep(sleepTimeMs);
+        rc = reg_access_mirc(_mf, REG_ACCESS_METHOD_GET, &mirc);
+        if (rc) {
+            DPRINTF(("2 reg_access_mirc failed rc = %d\n", rc));
+            _lastError = regErrTrans(rc);
+            return false;
+        }
+        DPRINTF(("1 mirc.status_code = %d\n", mirc.status_code));
+        while (mirc.status_code == IMAGE_REACTIVATION_BUSY) {
+            msleep(sleepTimeMs);
+            rc = reg_access_mirc(_mf, REG_ACCESS_METHOD_GET, &mirc);
+            deal_with_signal();
+            if (rc) {
+                _lastError = regErrTrans(rc);
+                setLastRegisterAccessStatus(rc);
+                DPRINTF(("3 reg_access_mirc failed rc = %d\n", rc));
+                return false;
+            }
+            DPRINTF(("2 iteration %d mirc.status_code = %d\n", currentIteration++,  mirc.status_code));
+            if (currentIteration >= maxNumOfIterations) {
+                _lastError = FWCOMPS_IMAGE_REACTIVATION_WAITING_TIME_EXPIRED;
+                return false;
+            }
+        } 
+    }
+    if (mirc.status_code == IMAGE_REACTIVATION_SUCCESS) {
+        return true;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_PROHIBITED_FW_VER_ERR) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_PROHIBITED_FW_VER_ERR;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_FIRST_PAGE_COPY_FAILED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FIRST_PAGE_COPY_FAILED;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_FIRST_PAGE_ERASE_FAILED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FIRST_PAGE_ERASE_FAILED;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_FIRST_PAGE_RESTORE_FAILED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FIRST_PAGE_RESTORE_FAILED;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_FW_DEACTIVATION_FAILED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FW_DEACTIVATION_FAILED;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_FW_ALREADY_ACTIVATED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FW_ALREADY_ACTIVATED;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_ERROR_DEVICE_RESET_REQUIRED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_ERROR_DEVICE_RESET_REQUIRED;
+    }
+    else if (mirc.status_code == IMAGE_REACTIVATION_FW_PROGRAMMING_NEEDED) {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_FW_PROGRAMMING_NEEDED;
+    }
+    else {
+        _lastError = FWCOMPS_IMAGE_REACTIVATION_UNKNOWN_ERROR;
+    }
+    return false;
+}
+
+
+
+void FwCompsMgr::setLastFirmwareError(fw_comps_error_t fw_error)
+{
+    _lastError = fw_error;
+}
+
+void FwCompsMgr::setLastRegisterAccessStatus(reg_access_status_t err)
 {
     _lastRegAccessStatus = err;
+}
+
+fw_comps_error_t FwCompsMgr::regErrTrans(reg_access_status_t err)
+{
     switch (err) {
     case ME_REG_ACCESS_OK:
         return FWCOMPS_REG_ACCESS_OK;
@@ -1343,7 +1469,7 @@ fw_comps_error_t FwCompsMgr::mccErrTrans(u_int8_t err)
         return FWCOMPS_MCC_REJECTED_IMAGE_CAN_NOT_BOOT_FROM_PARTITION;
 
     default:
-//            printf("MCC ERROR: %#x\n", err);
+        //            printf("MCC ERROR: %#x\n", err);
         return FWCOMPS_GENERAL_ERR;
     }
 }
