@@ -43,21 +43,20 @@
 #include <compatibility.h>
 
 #include "mflash_common_structs.h"
+#define MAX_FLASH_PROG_SEM_RETRY_CNT 40
 
-#define BOOT_CR_SPACE_ADDR 0xf0000
-
-int sx_get_flash_info_by_type(mflash* mfl, flash_info_t* type_index, int *log2size, u_int8_t *no_flash);
-int sx_block_read_by_type(mflash* mfl, u_int32_t blk_addr, u_int32_t blk_size, u_int8_t* data);
-int sx_block_write_by_type(mflash* mfl, u_int32_t addr, u_int32_t size, u_int8_t* data);
-int sx_flash_lock_by_type(mflash* mfl, int lock_state);
-int sx_erase_sect_by_type(mflash* mfl, u_int32_t addr, u_int32_t erase_size);
-int mf_update_boot_addr_by_type(mflash* mfl, u_int32_t boot_addr);
-int     sx_set_quad_en (mflash *mfl, u_int8_t quad_en);
-int     sx_get_quad_en (mflash *mfl, u_int8_t *quad_en);
+int sx_get_flash_info_by_type(mflash *mfl, flash_info_t *type_index, int *log2size, u_int8_t *no_flash);
+int sx_block_read_by_type(mflash *mfl, u_int32_t blk_addr, u_int32_t blk_size, u_int8_t *data);
+int sx_block_write_by_type(mflash *mfl, u_int32_t addr, u_int32_t size, u_int8_t *data);
+int sx_flash_lock_by_type(mflash *mfl, int lock_state);
+int sx_erase_sect_by_type(mflash *mfl, u_int32_t addr, u_int32_t erase_size);
+int mf_update_boot_addr_by_type(mflash *mfl, u_int32_t boot_addr);
+int     sx_set_quad_en(mflash *mfl, u_int8_t quad_en);
+int     sx_get_quad_en(mflash *mfl, u_int8_t *quad_en);
 int     sx_set_write_protect(mflash *mfl, u_int8_t bank_num, write_protect_info_t *protect_info);
 int     sx_get_write_protect(mflash *mfl, u_int8_t bank_num, write_protect_info_t *protect_info);
-int     sx_set_dummy_cycles (mflash *mfl, u_int8_t num_of_cycles);
-int     sx_get_dummy_cycles (mflash *mfl, u_int8_t *num_of_cycles);
+int     sx_set_dummy_cycles(mflash *mfl, u_int8_t num_of_cycles);
+int     sx_get_dummy_cycles(mflash *mfl, u_int8_t *num_of_cycles);
 
 
 #endif /* MFLASH_ACCESS_LAYER_H_ */
