@@ -50,6 +50,13 @@
 #include "../tools_layouts/tools_open_layouts.h"
 #include "mlxcfg_utils.h"
 
+#if __cplusplus >= 201402L
+#include <regex>
+#elif !defined(MST_UL)
+#include <boost/regex.hpp>
+using namespace boost;
+#endif
+
 using namespace std;
 
 typedef struct reg_access_hca_mqis_reg mqisReg;
@@ -301,6 +308,35 @@ string parseIndexStr(const string& indexedMlxconfigName)
                                        pr - pl - 1);
 }
 
+string increaseIndexIfNeeded(const string& name)
+{
+    string increasedName = name;
+
+    if (isIndexedMlxconfigName(name)) {
+        size_t pl = name.find('[');
+        size_t pr = name.find(']');
+        if (isIndexedStartFromOneSupported(name.substr(0,pl))) {
+            u_int32_t increasedIndex = 0;
+            if (strToNum(name.substr(pl + 1, pr - pl - 1), increasedIndex)) {
+                increasedIndex++;
+                increasedName = name.substr(0, pl) + "[" + numToStr(increasedIndex) + "]";
+            }
+        }
+    }
+
+    return increasedName;
+}
+
+bool isIndexedStartFromOneSupported(const string& mlxconfigName)
+{
+#if defined(MST_UL)
+    (void)mlxconfigName;
+    return false;
+#else
+    return mlxconfigName == "SPLIT_PORT";
+#endif
+}
+
 void parseIndexedMlxconfigName(const string& indexedMlxconfigName, string& mlxconfigName, u_int32_t& index)
 {
     string indexStr = parseIndexStr(indexedMlxconfigName);
@@ -352,6 +388,44 @@ bool isIndexedMlxconfigName(const string& mlxconfigName)
     return (mlxconfigName.find("[") != string::npos);
 }
 
+string getArraySuffix(const string& mlxconfigName)
+{
+#if defined(MST_UL)
+    (void)mlxconfigName;
+    return "";
+#else
+    static const regex EXP_PATTERN("(_[0-9]{2}_[0-9]+)");
+    string suffix = "";
+    smatch match;
+
+    if (regex_search(mlxconfigName, match, EXP_PATTERN)) {
+        suffix = match.str();
+    }
+    
+    return suffix;
+#endif
+}
+
+string getArrayPrefix(const string& mlxconfigName)
+{
+    string prefix = mlxconfigName;
+
+    return prefix.substr(0, mlxconfigName.size() - getArraySuffix(mlxconfigName).size());
+}
+
+string getArraySuffixByInterval(u_int32_t interval)
+{
+    string suffix = "_";
+    u_int32_t low_bound = ((interval / MAX_ARRAY_SIZE) * MAX_ARRAY_SIZE) + 1;
+    u_int32_t upper_bound = low_bound + MAX_ARRAY_SIZE - 1;
+    
+    suffix += numToStr(upper_bound) + "_" + numToStr(low_bound);
+
+    return suffix;
+}
+
+
+
 bool getDeviceInformationString(const char* dev, info_type_t op, vector<char>& infoString)
 {
     mqisReg mqisRegister;
@@ -361,11 +435,7 @@ bool getDeviceInformationString(const char* dev, info_type_t op, vector<char>& i
        return false;
     }
     reg_access_status_t rc;
-    int maxDataSize = mget_max_reg_size(mf, MACCESS_REG_METHOD_GET) - sizeof(mqisRegister);
-    if (maxDataSize > MAX_REG_DATA) {
-        maxDataSize = sizeof(mqisRegister);
-    }
-    std::vector<u_int32_t> dataVector(maxDataSize / 4, 0);
+    int maxDataSize = sizeof(mqisRegister.info_string);
 
     memset(&mqisRegister, 0, sizeof(mqisReg));
     if (op == Device_Name){
@@ -377,7 +447,6 @@ bool getDeviceInformationString(const char* dev, info_type_t op, vector<char>& i
         return false;
     }
     mqisRegister.read_length = maxDataSize;
-    mqisRegister.info_string = dataVector.data();
     mft_signal_set_handling(1);
 
     rc = reg_access_mqis(mf, REG_ACCESS_METHOD_GET, &mqisRegister);
@@ -391,26 +460,29 @@ bool getDeviceInformationString(const char* dev, info_type_t op, vector<char>& i
         return false;
     }
     infoString.resize(infoSize+1, 0);
-    if (mqisRegister.info_length > maxDataSize) {
-        dataVector.resize((infoSize + 3) / 4);
-        int leftSize = infoSize - maxDataSize;
+
+    // copy the output
+    memcpy(infoString.data(), mqisRegister.info_string,
+            mqisRegister.read_length);
+
+    if (infoSize > mqisRegister.read_length) {
+        int leftSize = infoSize - mqisRegister.read_length;
         while (leftSize > 0) {
             mqisRegister.read_offset = infoSize - leftSize;
             mqisRegister.read_length = leftSize > maxDataSize ? maxDataSize : leftSize;
-            mqisRegister.info_string = dataVector.data() + (mqisRegister.read_offset / 4);
             mft_signal_set_handling(1);
 
             rc = reg_access_mqis(mf, REG_ACCESS_METHOD_GET, &mqisRegister);
             dealWithSignal();
             if (rc) {
-               mclose(mf);
                return false;
             }
-            leftSize = leftSize - maxDataSize;
+            memcpy(infoString.data() + mqisRegister.read_offset,
+                   (mqisRegister.info_string), mqisRegister.read_length);
+            leftSize -= mqisRegister.read_length;
         }
     }
 
-    memcpy(infoString.data(), dataVector.data(), infoSize);
     mclose(mf);
     string str = string (infoString.data());
     if (str.length() == 0) {
