@@ -183,7 +183,7 @@ bool Fs4Operations::getHWPtrs(VerifyCallBack verifyCallBackFunc)
     return true;
 }
 
-bool Fs4Operations::getExtendedHWPtrs(VerifyCallBack verifyCallBackFunc)
+bool Fs4Operations::getExtendedHWPtrs(VerifyCallBack verifyCallBackFunc, FBase* ioAccess, bool IsBurningProcess)
 {
 
     //TODO
@@ -195,9 +195,12 @@ bool Fs4Operations::getExtendedHWPtrs(VerifyCallBack verifyCallBackFunc)
     const unsigned int s = CX6FW_HW_POINTERS_SIZE / 4;
     u_int32_t buff[s];
     struct cx6fw_hw_pointers hw_pointers;
-    u_int32_t physAddr = _fwImgInfo.imgStart + FS4_HW_PTR_START;
+    u_int32_t physAddr = FS4_HW_PTR_START;
+    if (!IsBurningProcess) {
+        physAddr += _fwImgInfo.imgStart;
+    }
 
-    READBUF((*_ioAccess),
+    READBUF((*ioAccess),
             physAddr,
             buff,
             CX6FW_HW_POINTERS_SIZE,
@@ -325,7 +328,7 @@ bool Fs4Operations::verifyTocHeader(u_int32_t tocAddr, bool isDtoc, VerifyCallBa
 }
 
 bool Fs4Operations::verifyTocEntries(u_int32_t tocAddr, bool show_itoc, bool isDtoc,
-                                     struct QueryOptions queryOptions, VerifyCallBack verifyCallBackFunc)
+                                     struct QueryOptions queryOptions, VerifyCallBack verifyCallBackFunc, bool verbose)
 {
 
     struct cx5fw_itoc_entry tocEntry;
@@ -348,8 +351,20 @@ bool Fs4Operations::verifyTocEntries(u_int32_t tocAddr, bool show_itoc, bool isD
 
     do {
         // Read toc entry
+        if (nextBootFwVer) {
+            // if nextBootFwVer is true, read only fw version (FS3_IMAGE_INFO section)
+            // section index should be 8 for this case
+            section_index = 8;
+        }
         entryAddr = tocAddr + TOC_HEADER_SIZE + section_index *  TOC_ENTRY_SIZE;
+        if (!verbose) {
         READBUF((*_ioAccess), entryAddr, entryBuffer, TOC_ENTRY_SIZE, "TOC Entry");
+        }
+        else {
+            if (!(*_ioAccess).read(entryAddr, entryBuffer, TOC_ENTRY_SIZE, true)) {
+                return errmsg("%s - read error (%s)\n", "TOC Entry", (*_ioAccess).err());
+            }
+        }
         Fs3UpdateImgCache(entryBuffer, entryAddr, TOC_ENTRY_SIZE);
         cx5fw_itoc_entry_unpack(&tocEntry, entryBuffer);
 
@@ -400,7 +415,7 @@ bool Fs4Operations::verifyTocEntries(u_int32_t tocAddr, bool show_itoc, bool isD
 
                 // Only when we have full verify or the info of this section should be collected for query
                 std::vector<u_int8_t> buffv(entrySizeInBytes);
-                u_int8_t *buff = (u_int8_t *)(&(buffv[0]));
+                u_int8_t *buff = (u_int8_t *)(buffv.size() ? (&(buffv[0])) : NULL);
 
                 if (show_itoc) {
                     cx5fw_itoc_entry_dump(&tocEntry, stdout);
@@ -409,7 +424,14 @@ bool Fs4Operations::verifyTocEntries(u_int32_t tocAddr, bool show_itoc, bool isD
                         retVal = false;
                     }
                 } else {
+                    if (!verbose) {
                     READBUF((*_ioAccess), flash_addr, buff, entrySizeInBytes, "Section");
+                    }
+                    else {
+                        if (!(*_ioAccess).read(flash_addr, buff, entrySizeInBytes, true)) {
+                            return errmsg("%s - read error (%s)\n", "Section", (*_ioAccess).err());
+                        }
+                    }
                     Fs3UpdateImgCache(buff, flash_addr, entrySizeInBytes);
                     u_int32_t sect_act_crc = 0;
                     u_int32_t sect_exp_crc = 0;
@@ -473,7 +495,10 @@ bool Fs4Operations::verifyTocEntries(u_int32_t tocAddr, bool show_itoc, bool isD
                    entryBuffer, CX5FW_ITOC_ENTRY_SIZE);
 
         }
-
+        if (nextBootFwVer) {
+            // if nextBootFwVer, return after reading fw version
+            break;
+        }
         section_index++;
     } while (tocEntry.type != FS3_END);
 
@@ -504,7 +529,7 @@ bool Fs4Operations::verifyTocEntries(u_int32_t tocAddr, bool show_itoc, bool isD
 
 
 bool Fs4Operations::FsVerifyAux(VerifyCallBack verifyCallBackFunc, bool show_itoc,
-                                struct QueryOptions queryOptions, bool ignoreDToc)
+                                struct QueryOptions queryOptions, bool ignoreDToc, bool verbose)
 {
     u_int32_t dtocPtr;
     u_int8_t *buff;
@@ -522,39 +547,59 @@ bool Fs4Operations::FsVerifyAux(VerifyCallBack verifyCallBackFunc, bool show_ito
     if (!getHWPtrs(verifyCallBackFunc)) {
         return false;
     }
-
-    if (!verifyToolsArea(verifyCallBackFunc)) {
-        return false;
-    }
+    // if nextBootFwVer is true, no need to get all the information, just the fw version is enough - therefore skip everything else
+    if (!nextBootFwVer) {
+        if (!verifyToolsArea(verifyCallBackFunc)) {
+            return false;
+        }
 
     // Update image cache till before boot2 header:
-    READALLOCBUF((*_ioAccess), _fwImgInfo.imgStart, buff, _boot2_ptr, "All Before Boot2");
-    Fs3UpdateImgCache(buff, 0, _boot2_ptr);
-    free(buff);
+        READALLOCBUF((*_ioAccess), _fwImgInfo.imgStart, buff, _boot2_ptr, "All Before Boot2");
+        Fs3UpdateImgCache(buff, 0, _boot2_ptr);
+        free(buff);
 
-    _ioAccess->set_address_convertor(_fwImgInfo.cntxLog2ChunkSize, _fwImgInfo.imgStart != 0);
+        _ioAccess->set_address_convertor(_fwImgInfo.cntxLog2ChunkSize, _fwImgInfo.imgStart != 0);
 
     // Get BOOT2 -Get Only bootSize if quickQuery == true else read and check CRC of boot2 section as well
-    FS3_CHECKB2(0, _boot2_ptr, !queryOptions.quickQuery, PRE_CRC_OUTPUT, verifyCallBackFunc);
+        FS3_CHECKB2(0, _boot2_ptr, !queryOptions.quickQuery, PRE_CRC_OUTPUT, verifyCallBackFunc);
 
-    _fs4ImgInfo.firstItocArrayIsEmpty = false;
-    _fs4ImgInfo.itocArr.tocArrayAddr = _itoc_ptr;
+        _fs4ImgInfo.firstItocArrayIsEmpty = false;
+        _fs4ImgInfo.itocArr.tocArrayAddr = _itoc_ptr;
 
     /*printf("\n-D-_ioAccess size=0x%x\n", _ioAccess->get_size());
        printf("\n-D-dtoc_ptr=0x%x\n", dtoc_ptr);*/
 
-    if (!verifyTocHeader(_itoc_ptr, false, verifyCallBackFunc)) {
-        _itoc_ptr += FS4_DEFAULT_SECTOR_SIZE;
-        _fs4ImgInfo.itocArr.tocArrayAddr = _itoc_ptr;
-        _fs4ImgInfo.firstItocArrayIsEmpty = true;
         if (!verifyTocHeader(_itoc_ptr, false, verifyCallBackFunc)) {
-            return errmsg(MLXFW_NO_VALID_ITOC_ERR, "No valid ITOC Header was found.");
+            _itoc_ptr += FS4_DEFAULT_SECTOR_SIZE;
+            _fs4ImgInfo.itocArr.tocArrayAddr = _itoc_ptr;
+            _fs4ImgInfo.firstItocArrayIsEmpty = true;
+            if (!verifyTocHeader(_itoc_ptr, false, verifyCallBackFunc)) {
+                return errmsg(MLXFW_NO_VALID_ITOC_ERR, "No valid ITOC Header was found.");
+            }
         }
     }
+    if (_ioAccess->is_flash() == false && _signatureDataSet == false) {
+        int signature_size = 3 * HMAC_SIGNATURE_LENGTH;
+        uint8_t signature_data[3 * HMAC_SIGNATURE_LENGTH] = { 0 };
+        int signature_offset = _digest_mdk_ptr;
+        if (signature_offset == 0) {
+            signature_offset = _digest_recovery_key_ptr;
+        }
+        READBUF((*_ioAccess),
+            signature_offset,
+            signature_data,
+            signature_size,
+            "Reading data pointed by HW MDK Pointer");
+        Fs3UpdateImgCache(signature_data, signature_offset, signature_size);
+        _signatureDataSet = true;
+    }
     if (!verifyTocEntries(_itoc_ptr, show_itoc, false,
-                          queryOptions, verifyCallBackFunc)) {
+                          queryOptions, verifyCallBackFunc, verbose)) {
         return false;
     }
+    if (nextBootFwVer) {
+        return true;
+    }
     if (ignoreDToc) {
         return true;
     }
@@ -570,7 +615,7 @@ bool Fs4Operations::FsVerifyAux(VerifyCallBack verifyCallBackFunc, bool show_ito
     _fs4ImgInfo.dtocArr.tocArrayAddr = dtocPtr;
     //-Verify DToC Entries:
     if (!verifyTocEntries(dtocPtr, show_itoc, true,
-                          queryOptions, verifyCallBackFunc)) {
+                          queryOptions, verifyCallBackFunc, verbose)) {
         _ioAccess->set_address_convertor(log2_chunk_size, is_image_in_odd_chunks);
         return false;
     }
@@ -604,7 +649,7 @@ bool Fs4Operations::CheckFs4ImgSize(Fs4Operations& imageOps, bool useImageDevDat
                       imageOps._maxImgLog2Size);
     }
 
-    //check if minimal dtoc is not overwriting the preceeding chunk
+    //check if minimal dtoc is not overwriting the preceding chunk
     if (useImageDevData) {
         u_int32_t devAreaStartAddress = _ioAccess->get_size() - (1 << imageOps._maxImgLog2Size);
         if (imageOps._fs4ImgInfo.smallestDTocAddr < devAreaStartAddress) {
@@ -618,7 +663,7 @@ bool Fs4Operations::CheckFs4ImgSize(Fs4Operations& imageOps, bool useImageDevDat
     return true;
 }
 
-bool Fs4Operations::FwReadData(void *image, u_int32_t *imageSize)
+bool Fs4Operations::FwReadData(void *image, u_int32_t *imageSize, bool verbose)
 {
     struct QueryOptions queryOptions;
     if (!imageSize) {
@@ -633,7 +678,7 @@ bool Fs4Operations::FwReadData(void *image, u_int32_t *imageSize)
         queryOptions.quickQuery = true;
     }
     // Avoid Warning
-    if (!FsVerifyAux((VerifyCallBack)NULL, 0, queryOptions)) {
+    if (!FsVerifyAux((VerifyCallBack)NULL, 0, queryOptions, false, verbose)) {
         return false;
     }
 
@@ -1336,11 +1381,26 @@ bool Fs4Operations::BurnFs4Image(Fs4Operations &imageOps,
     if (!f->is_flash()) {
         return true;
     }
-
-    if (!AddHMACIfNeeded(&imageOps, f)) {
+    bool IsUpdateSignatures = true;
+    switch (this->_fwImgInfo.ext_info.chip_type) {
+        case CT_CONNECTX6:
+            getExtendedHWPtrs((VerifyCallBack)NULL, imageOps._ioAccess, true);
+            break;
+        default:
+            IsUpdateSignatures = false;
+            break;
+    }
+    if (IsUpdateSignatures) {
+        u_int32_t imageOffset = _digest_mdk_ptr;
+        if (imageOffset == 0) {
+            imageOffset = _digest_recovery_key_ptr;
+        }
+        if (imageOffset != 0) {
+            if (!_signatureMngr->AddSignature(_ioAccess->getMfileObj(), &imageOps, f, imageOffset)) {
         return false;
     }
-
+        }
+    }
     // Write new signature
     data8 = new u_int8_t[FS3_FW_SIGNATURE_SIZE];
     imageOps._imageCache.get(data8, 0, FS3_FW_SIGNATURE_SIZE);
@@ -2274,7 +2334,7 @@ bool Fs4Operations::FwSignWithHmac(const char *keyFile)
     if (_ioAccess->is_flash()) {
         return errmsg( "Adding HMAC not allowed for devices");
     }
-    if (!getExtendedHWPtrs((VerifyCallBack)NULL)) {
+    if (!getExtendedHWPtrs((VerifyCallBack)NULL, _ioAccess)) {
         return false;
     }
     const unsigned int s = _authentication_end_ptr - _authentication_start_ptr + 1;
@@ -2366,6 +2426,31 @@ bool Fs4Operations::PrepItocSectionsForHmac(vector<u_int8_t>& critical, vector<u
     }
     return true;
 }
+bool Fs4Operations::PrepItocSectionsForCompare(vector<u_int8_t>& critical, vector<u_int8_t>& non_critical)
+{
+    for (int i = 0; i < this->_fs4ImgInfo.itocArr.numOfTocs; i++) {
+        struct fs4_toc_info *itoc_info_p = &this->_fs4ImgInfo.itocArr.tocArr[i];
+        struct cx5fw_itoc_entry *toc_entry = &(itoc_info_p->toc_entry);
+        if (IsCriticalSection(toc_entry->type))
+        {
+            critical.reserve(critical.size() + itoc_info_p->section_data.size());
+            critical.insert(critical.end(), itoc_info_p->section_data.begin(), itoc_info_p->section_data.end());
+            //printf("-D- addr  0x%.8x toc type : 0x%.8x  size 0x%.8x name %s\n", itoc_info_p->entry_addr, itoc_info_p->toc_entry.type, 
+                //(unsigned int)(itoc_info_p->section_data.size() + padding_size), GetSectionNameByType(itoc_info_p->toc_entry.type));
+        }
+        else
+        {
+            if (itoc_info_p->toc_entry.type == FS3_IMAGE_SIGNATURE_512 || itoc_info_p->toc_entry.type == FS3_IMAGE_SIGNATURE_256) {
+                continue;
+            }
+            //printf("-D- addr  0x%.8x toc type : 0x%.8x  size 0x%.8x name %s\n", itoc_info_p->entry_addr, itoc_info_p->toc_entry.type, (unsigned int)itoc_info_p->section_data.size(), GetSectionNameByType(itoc_info_p->toc_entry.type));
+            non_critical.reserve(non_critical.size() + itoc_info_p->section_data.size());
+            non_critical.insert(non_critical.end(), itoc_info_p->section_data.begin(), itoc_info_p->section_data.end());
+            //currentItoc++;
+        }
+    }
+    return true;
+}
 
 bool Fs4Operations::IsCriticalSection(u_int8_t sect_type)
 {
@@ -2384,7 +2469,6 @@ bool Fs4Operations::CalcHMAC(const vector<u_int8_t>& key, const vector<u_int8_t>
     return true;
 #else
     (void)key;
-    (void)data;
     (void)digest;
     return errmsg("HMAC calculation is not implemented\n");
 #endif
