@@ -134,9 +134,6 @@ int FwOperations::getMfaImgInner(char *fileName, u_int8_t *mfa_buf, int size,
     if (res) {
         res = res < 0 ? res : -1 * res;
         WriteToErrBuff(errBuf, "Failed to open mfa file", errBufSize);
-        if (mfa_d) {
-            mfa_close(mfa_d);
-        }
         return res;
     }
 
@@ -444,8 +441,8 @@ bool FwOperations::FindAllImageStart(FBase *ioAccess,
     needed_pos_num = CNTX_START_POS_SIZE;
 
     if (ioAccess->is_flash()) {
-        if ( (((Flash*)ioAccess)->get_dev_id() == CX2_HW_ID) ||
-             (((Flash*)ioAccess)->get_dev_id() == IS4_HW_ID)) {
+        if ( (ioAccess->get_dev_id() == CX2_HW_ID) ||
+             (ioAccess->get_dev_id() == IS4_HW_ID)) {
             needed_pos_num = OLD_CNTX_START_POS_SIZE;
         }
     }
@@ -454,7 +451,7 @@ bool FwOperations::FindAllImageStart(FBase *ioAccess,
      *     valid image to be found. as a WA we dont check at 0x400000. basic flash operations
      *     are affected when attempting to access addressess greater than 0x3fffff.
      */
-    if (((Flash*)ioAccess)->get_dev_id() == SWITCH_IB_HW_ID) {
+    if (ioAccess->get_dev_id() == SWITCH_IB_HW_ID) {
         needed_pos_num -= 1;
     }
 
@@ -569,14 +566,14 @@ bool FwOperations::FwAccessCreate(fw_ops_params_t& fwParams, FBase **ioAccessP)
 #endif
     } else if (fwParams.hndlType == FHT_UEFI_DEV) {
         *ioAccessP = new Flash;
-        if (!((Flash*)*ioAccessP)->open(fwParams.uefiHndl, fwParams.uefiExtra, false, !fwParams.shortErrors)) {
+        if (!(*ioAccessP)->open(fwParams.uefiHndl, &fwParams.uefiExtra, false, !fwParams.shortErrors)) {
             WriteToErrBuff(fwParams.errBuff, (*ioAccessP)->err(), fwParams.errBuffSize);
             delete *ioAccessP;
             return false;
         }
     } else if (fwParams.hndlType == FHT_MST_DEV) {
         *ioAccessP = new Flash;
-        if (!((Flash*)*ioAccessP)->open(fwParams.mstHndl, fwParams.forceLock, fwParams.readOnly, fwParams.numOfBanks, \
+        if (!(*ioAccessP)->open(fwParams.mstHndl, fwParams.forceLock, fwParams.readOnly, fwParams.numOfBanks, \
                                         fwParams.flashParams, fwParams.ignoreCacheRep, !fwParams.shortErrors, fwParams.cx3FwAccess)) {
             // TODO: release memory here ?
             WriteToErrBuff(fwParams.errBuff, (*ioAccessP)->err(), fwParams.errBuffSize);
@@ -584,9 +581,9 @@ bool FwOperations::FwAccessCreate(fw_ops_params_t& fwParams, FBase **ioAccessP)
             return false;
         }
         //set no flash verify if needed (default =false)
-        ((Flash*)*ioAccessP)->set_no_flash_verify(fwParams.noFlashVerify);
+        (*ioAccessP)->set_no_flash_verify(fwParams.noFlashVerify);
         // work with 64KB sector size if possible to increase performace in full fw burn
-        (((Flash*)*ioAccessP)->set_flash_working_mode(Flash::Fwm_64KB));
+        ((*ioAccessP)->set_flash_working_mode(Flash::Fwm_64KB));
     } else {
         WriteToErrBuff(fwParams.errBuff, "Unknown Handle Type.", fwParams.errBuffSize);
         return false;
@@ -653,7 +650,7 @@ u_int8_t FwOperations::CheckFwFormat(FBase& f, bool getFwFormatFromImg)
     u_int32_t found_images = 0;
 
     if (f.is_flash() && !getFwFormatFromImg) {
-        return GetFwFormatFromHwDevID(((Flash*)&f)->get_dev_id());
+        return GetFwFormatFromHwDevID(f.get_dev_id());
     } else {
         v = IsCableImage(f);
         if (v != FS_UNKNOWN_IMG) {
@@ -714,7 +711,7 @@ FwOperations* FwOperations::FwOperationsCreate(void *fwHndl, void *info, char *p
         fwParams.buffSize = *((u_int32_t*)info);
     } else if (hndlType == FHT_UEFI_DEV) {
         fwParams.uefiHndl = (uefi_Dev_t*)fwHndl;
-        fwParams.uefiExtra = (uefi_dev_extra_t*)info;
+        fwParams.uefiExtra = *(uefi_dev_extra_t*)info;
     } else if (hndlType == FHT_MST_DEV) {
         fwParams.mstHndl = (char*)fwHndl;
         fwParams.forceLock = false;
@@ -730,7 +727,7 @@ FwOperations* FwOperations::FwOperationsCreate(void *fwHndl, void *info, char *p
     return FwOperationsCreate(fwParams);
 }
 
-bool FwOperations::imageDevOperationsCreate(fw_ops_params_t& devParams, fw_ops_params_t& imgParams, FwOperations **devFwOps, FwOperations **imgFwOps)
+bool FwOperations::imageDevOperationsCreate(fw_ops_params_t& devParams, fw_ops_params_t& imgParams, FwOperations **devFwOps, FwOperations **imgFwOps, bool ignoreSecurityAttributes, bool ignoreDToc)
 {
     *imgFwOps = FwOperationsCreate(imgParams);
     if (!(*imgFwOps)) {
@@ -747,10 +744,10 @@ bool FwOperations::imageDevOperationsCreate(fw_ops_params_t& devParams, fw_ops_p
 
     fw_info_t imgQuery;
     memset(&imgQuery, 0, sizeof(fw_info_t));
-    if (!(*imgFwOps)->FwQuery(&imgQuery)) {
+    if (!(*imgFwOps)->FwQuery(&imgQuery, true, false, true, ignoreDToc)) {
         return false;
     }
-    if (imgQuery.fs3_info.security_mode == SM_NONE) {
+    if (imgQuery.fs3_info.security_mode == SM_NONE && ignoreSecurityAttributes == false) {
         devParams.noFwCtrl = true;
     }
     *devFwOps = FwOperationsCreate(devParams);
@@ -807,21 +804,27 @@ FwOperations* FwOperations::FwOperationsCreate(fw_ops_params_t& fwParams)
     {
         if ((!fwParams.ignoreCacheRep && !fwParams.noFwCtrl && fwParams.hndlType == FHT_MST_DEV) ||
             (fwParams.hndlType == FHT_UEFI_DEV     &&
-             fwParams.uefiExtra != NULL           &&
-             fwParams.uefiExtra->dev_info != NULL &&
-             !fwParams.uefiExtra->dev_info->no_fw_ctrl)) {
+             !fwParams.uefiExtra.dev_info.no_fw_ctrl)) {
             if (fwParams.hndlType == FHT_MST_DEV) {
                 fwCompsAccess = new FwCompsMgr(fwParams.mstHndl);
             } else if (fwParams.hndlType == FHT_UEFI_DEV) {
-                fwCompsAccess = new FwCompsMgr(fwParams.uefiHndl, fwParams.uefiExtra);
+                fwCompsAccess = new FwCompsMgr(fwParams.uefiHndl, &fwParams.uefiExtra);
             }
             fw_comps_error_t fwCompsErr = fwCompsAccess->getLastError();
             if (fwCompsErr != FWCOMPS_SUCCESS) {
-                delete fwCompsAccess;
-                fwCompsAccess = (FwCompsMgr*) NULL;
+                bool exitOnError = false;
                 if (fwCompsErr == FWCOMPS_MTCR_OPEN_DEVICE_ERROR) {
                     // mtcr lib failed to open the provided device.
                     WriteToErrBuff(fwParams.errBuff, "Failed to open device", fwParams.errBuffSize);
+                    exitOnError = true;
+                }
+                else if(fwCompsErr == FWCOMPS_REG_ACCESS_RES_NOT_AVLBL) {
+                    WriteToErrBuff(fwParams.errBuff, fwCompsAccess->getLastErrMsg(), fwParams.errBuffSize);
+                    exitOnError = true;
+                }
+                delete fwCompsAccess;
+                fwCompsAccess = (FwCompsMgr*) NULL;
+                if (exitOnError) {
                     return (FwOperations*)NULL;
                 }
             } else {
@@ -852,11 +855,12 @@ FwOperations* FwOperations::FwOperationsCreate(fw_ops_params_t& fwParams)
         fwFormat = CheckFwFormat(*ioAccess, getFwFormatFromImg);
 init_fwops:
         switch (fwFormat) {
+#if !defined(UEFI_BUILD)
         case FS_FS2_GEN: {
                 fwops = new Fs2Operations(ioAccess);
                 break;
             }
-
+#endif
         case FS_FS3_GEN: {
                 fwops = new Fs3Operations(ioAccess);
                 break;
@@ -898,6 +902,7 @@ init_fwops:
         if (fwParams.hndlType == FHT_MST_DEV) {
             fwops->_devName = strcpy(new char[strlen(fwParams.mstHndl) + 1], fwParams.mstHndl);
         }
+        fwops->CreateSignatureManager();
     }
     return fwops;
 }
@@ -918,6 +923,7 @@ bool FwOperations::writeImageEx(ProgressCallBackEx progressFuncEx, void *progres
     u_int8_t   *p = (u_int8_t*)data;
     u_int32_t curr_addr = addr;
     u_int32_t towrite = cnt;
+    u_int32_t last_percent = 0xff;
     totalSz = totalSz == -1 ? cnt : totalSz;
     int origFlashWorkingMode = Flash::Fwm_Default;
     bool rc;
@@ -927,26 +933,26 @@ bool FwOperations::writeImageEx(ProgressCallBackEx progressFuncEx, void *progres
         if (_ioAccess->is_flash()) {
             if (readModifyWrite) {
                 // perform write with the smallest supported sector size
-                origFlashWorkingMode = ((Flash*)_ioAccess)->get_flash_working_mode();
-                ((Flash*)_ioAccess)->set_flash_working_mode(Flash::Fwm_Default);
+                origFlashWorkingMode = _ioAccess->get_flash_working_mode();
+                _ioAccess->set_flash_working_mode(Flash::Fwm_Default);
             }
             trans = (towrite > (int)Flash::TRANS) ? (int)Flash::TRANS : towrite;
             if (isPhysAddr) {
                 if (readModifyWrite) {
-                    rc = ((Flash*)_ioAccess)->read_modify_write_phy(curr_addr, p, trans);
+                    rc = _ioAccess->read_modify_write_phy(curr_addr, p, trans);
                 } else {
-                    rc = ((Flash*)_ioAccess)->write_phy(curr_addr, p, trans);
+                    rc = _ioAccess->write_phy(curr_addr, p, trans);
                 }
             } else {
                 if (readModifyWrite) {
-                    rc = ((Flash*)_ioAccess)->read_modify_write(curr_addr, p, trans);
+                    rc = _ioAccess->read_modify_write(curr_addr, p, trans);
                 } else {
-                    rc = ((Flash*)_ioAccess)->write(curr_addr, p, trans);
+                    rc = _ioAccess->write(curr_addr, p, trans);
                 }
             }
             if (readModifyWrite) {
                 // restore erase sector size
-                ((Flash*)_ioAccess)->set_flash_working_mode(origFlashWorkingMode);
+                _ioAccess->set_flash_working_mode(origFlashWorkingMode);
             }
             if (!rc) {
                 return errmsg(MLXFW_FLASH_WRITE_ERR, "Flash write failed: %s", _ioAccess->err());
@@ -963,15 +969,18 @@ bool FwOperations::writeImageEx(ProgressCallBackEx progressFuncEx, void *progres
 
         // Report
         if (progressFunc != NULL || progressFuncEx != NULL) {
-            u_int32_t new_perc = ((cnt - towrite + alreadyWrittenSz) * 100) / totalSz;
-            if (progressFunc != NULL && progressFunc((int)new_perc)) {
+            u_int32_t curr_percent = ((cnt - towrite + alreadyWrittenSz) * 100) / totalSz;
+            if(last_percent != curr_percent) {
+                last_percent = curr_percent;
+                if (progressFunc != NULL && progressFunc((int)curr_percent)) {
                 return errmsg("Aborting... received interrupt signal");
             }
-            if (progressFuncEx != NULL && progressFuncEx((int)new_perc, progressUserData)) {
+                if (progressFuncEx != NULL && progressFuncEx((int)curr_percent, progressUserData)) {
                 return errmsg("Aborting... received interrupt signal");
             }
         }
     }
+    }
     return true;
 } //  Flash::WriteImage
 
@@ -1032,8 +1041,9 @@ chip_type_t FwOperations::getChipType()
 bool FwOperations::getInfoFromHwDevid(u_int32_t hwDevId, chip_type_t& chipT, const u_int32_t **swIds)
 {
     int i = 0;
+    u_int32_t localDevId = hwDevId & 0xffff;//remove revison ID, it's not relevant here
     while (hwDevData[i].name != NULL) {
-        if (hwDevData[i].hwDevId == hwDevId) {
+        if (hwDevData[i].hwDevId == localDevId) {
             chipT = hwDevData[i].chipType;
             *swIds = hwDevData[i].swDevIds;
             return true;
@@ -1078,10 +1088,13 @@ const FwOperations::HwDevData FwOperations::hwDevData[] = {
                                                                                                {CX5_HIGH_BIN, {4119, 4121, 0}},
                                                                                                {UNKNOWN_BIN, {0}}}},
     { "ConnectX-6",       CX6_HW_ID,        CT_CONNECTX6,    CFT_HCA,     0, {4123, 0}, {{UNKNOWN_BIN, {0}}}},
+    { "ConnectX-6DX",     CX6DX_HW_ID,      CT_CONNECTX6DX,  CFT_HCA,     0, {4125, 0}, {{UNKNOWN_BIN, {0}}}},
     { "BlueField",        BF_HW_ID,         CT_BLUEFIELD,    CFT_HCA,     0, {41680, 41681, 41682, 0}, {{UNKNOWN_BIN, {0}}}},
     { "Spectrum",         SPECTRUM_HW_ID,   CT_SPECTRUM,     CFT_SWITCH,  0, {52100, 0}, {{UNKNOWN_BIN, {0}}}},
     { "Switch_IB2",       SWITCH_IB2_HW_ID, CT_SWITCH_IB2,   CFT_SWITCH,  0, {53000, 0}, {{UNKNOWN_BIN, {0}}}},
     { "Quantum",          QUANTUM_HW_ID,    CT_QUANTUM,      CFT_SWITCH,  0, {54000, 0}, {{UNKNOWN_BIN, {0}}}},
+    { "Spectrum2",        SPECTRUM2_HW_ID,  CT_SPECTRUM2,    CFT_SWITCH,  0, {53100, 0}, {{UNKNOWN_BIN, {0}}}},
+    { "Spectrum3",        SPECTRUM3_HW_ID,  CT_SPECTRUM3,    CFT_SWITCH,  0, {53104, 0}, {{UNKNOWN_BIN, {0}}}},
     { (char*)NULL,       0,                CT_UNKNOWN,      CFT_UNKNOWN, 0, {0}, {{UNKNOWN_BIN, {0}}}},// zero devid terminator
 };
 
@@ -1095,6 +1108,7 @@ const FwOperations::HwDev2Str FwOperations::hwDev2Str[] = {
     {"ConnectX-4LX",      CX4LX_HW_ID,      0x00},
     {"ConnectX-5",        CX5_HW_ID,        0x00},
     {"ConnectX-6",        CX6_HW_ID,        0x00},
+    {"ConnectX-6DX",      CX6DX_HW_ID,      0x00},
     {"BlueField",         BF_HW_ID,         0x00},
     {"SwitchX A0",        SWITCHX_HW_ID,    0x00},
     {"SwitchX A1",        SWITCHX_HW_ID,    0x01},
@@ -1105,6 +1119,8 @@ const FwOperations::HwDev2Str FwOperations::hwDev2Str[] = {
     {"SwitchIB2 A0",      SWITCH_IB2_HW_ID, 0x00},
     {"Quantum A0",        QUANTUM_HW_ID,    0x00},
     {"Spectrum A1",       SPECTRUM_HW_ID,   0x01},
+    {"Spectrum2 A0",      SPECTRUM2_HW_ID,  0x00},
+    {"Spectrum3 A0",      SPECTRUM3_HW_ID,  0x00},
     { (char*)NULL,       (u_int32_t)0, (u_int8_t)0x00},      // zero device ID terminator
 };
 
@@ -1290,7 +1306,7 @@ bool FwOperations::FwSwReset()
     if (!_ioAccess->is_flash()) {
         return errmsg("operation supported only for switch devices: InfiniScaleIV SwitchX and SwitchIB over an IB interface");
     }
-    if (!((Flash*)_ioAccess)->sw_reset()) {
+    if (!_ioAccess->sw_reset()) {
         return errmsg("%s",  _ioAccess->err());
     }
     return true;
@@ -1674,7 +1690,7 @@ void FwOperations::SetDevFlags(chip_type_t chipType, u_int32_t devType, fw_img_t
         ibDev  = (fwType == FIT_FS3 && chipType != CT_SPECTRUM) || (chipType == CT_CONNECTX && !CntxEthOnly(devType));
         ethDev = (chipType == CT_CONNECTX) || (chipType == CT_SPECTRUM) || (chipType == CT_CONNECTX4) || \
                  (chipType == CT_CONNECTX4_LX) || (chipType == CT_CONNECTX5) || (chipType == CT_BLUEFIELD) || \
-                 (chipType == CT_CONNECTX6);
+                 (chipType == CT_SPECTRUM2) || (chipType == CT_CONNECTX6)  || (chipType == CT_CONNECTX6DX);
     }
 
     if ((!ibDev && !ethDev) || chipType == CT_UNKNOWN) {
@@ -1735,7 +1751,7 @@ bool FwOperations::FwWriteBlock(u_int32_t addr, std::vector<u_int8_t> dataVec, P
     }
 
     //check if flash is big enough
-    if ((addr + dataVec.size()) > ((Flash*)_ioAccess)->get_size()) {
+    if ((addr + dataVec.size()) > _ioAccess->get_size()) {
         return errmsg("Writing %#x bytes from address %#x is out of flash limits (%#x bytes)\n",
                       (unsigned int)(dataVec.size()), (unsigned int)addr, (unsigned int)_ioAccess->get_size());
     }
@@ -1862,6 +1878,9 @@ const char* FwOperations::expRomType2Str(u_int16_t type)
     case 0x12:
         return "CLP";
 
+    case 0x13:
+        return "NVMe";
+
     case 0x21:
         return "FCODE";
 
@@ -1883,6 +1902,31 @@ bool FwOperations::FwResetTimeStamp()
     return errmsg("Operation not supported.");
 }
 
+bool FwOperations::FwBurnAdvanced(std::vector <u_int8_t> imageOps4MData, ExtBurnParams& burnParams)
+{
+    (void)imageOps4MData;
+    (void)burnParams;
+    return errmsg("Operation not supported.");
+}
+
+bool FwOperations::PrepItocSectionsForCompare(vector<u_int8_t>& critical, vector<u_int8_t>& non_critical)
+{
+    (void) critical;
+    (void) non_critical;
+    return errmsg("Operation not supported.");
+}
+
+bool FwOperations::Fs3UpdateSection(void *new_info, fs3_section_t sect_type, bool is_sect_failsafe, 
+    CommandType cmd_type, PrintCallBack callBackFunc)
+{
+    (void)new_info;
+    (void)sect_type;
+    (void)is_sect_failsafe;
+    (void)cmd_type;
+    (void)callBackFunc;
+    return errmsg("Operation not supported.");
+}
+
 bool FwOperations::FwQueryTimeStamp(struct tools_open_ts_entry& timestamp, struct tools_open_fw_version& fwVer, bool queryRunning)
 {
     (void)timestamp;
@@ -1940,10 +1984,11 @@ bool FwOperations::CalcHMAC(const vector<u_int8_t>& key, const vector<u_int8_t>&
     return errmsg("CalcHMAC not supported");
 }
 
-bool FwOperations::FwExtract4MBImage(vector<u_int8_t>& img, bool maskMagicPatternAndDevToc)
+bool FwOperations::FwExtract4MBImage(vector<u_int8_t>& img, bool maskMagicPatternAndDevToc, bool verbose)
 {
     (void)img;
     (void)maskMagicPatternAndDevToc;
+    (void)verbose;
     return errmsg("Operation not supported");
 }
 
@@ -1991,8 +2036,11 @@ u_int8_t FwOperations::GetFwFormatFromHwDevID(u_int32_t hwDevId)
         return FS_FS3_GEN;
     } else if (hwDevId == CX5_HW_ID ||
                hwDevId == CX6_HW_ID ||
+               hwDevId == CX6DX_HW_ID ||
                hwDevId == BF_HW_ID  ||
-               hwDevId == QUANTUM_HW_ID)  {
+               hwDevId == QUANTUM_HW_ID ||
+               hwDevId == SPECTRUM2_HW_ID ||
+               hwDevId == SPECTRUM3_HW_ID) {
         return FS_FS4_GEN;
     }
     return FS_UNKNOWN_IMG;
@@ -2003,7 +2051,6 @@ const char*  FwOperations::FwGetReSignMsgStr()
     return (const char*)NULL;
 }
 
-
 bool FwOperations::TestAndSetTimeStamp(FwOperations *imageOps)
 {
     Tlv_Status_t rc;
