@@ -44,17 +44,17 @@
 
 #define CRD_SELECT_CSV_PATH(dev_name) \
     do {                              \
-            strcat(csv_file_path, dev_name);\
-            strcat(csv_file_path, ".csv");\
+        strcat(csv_file_path, dev_name); \
+        strcat(csv_file_path, ".csv"); \
     } while (0)
 
 
-#define CRD_CHECK_NULL(var)\
+#define CRD_CHECK_NULL(var) \
     if (var == NULL)       \
         do {               \
-            CRD_DEBUG("Sent %s is null!\n", #var);\
+            CRD_DEBUG("Sent %s is null!\n", #var); \
             return CRD_INVALID_PARM;              \
-        } while(0)
+        } while (0)
 
 
 #if defined(__WIN__)
@@ -67,7 +67,7 @@
 #ifdef CRD_DEBUG_BUILD
 #    define CRD_DEBUG(fmt, ...)printf("%s:%s:%d: "fmt, __FILE__, __FUNCTION__, __LINE__,##__VA_ARGS__);
 #else
-#    define CRD_DEBUG(fmt, args...)
+#    define CRD_DEBUG(fmt, ...)
 #endif
 
 #define CRD_EMPTY  "EMPTY"
@@ -82,7 +82,7 @@ typedef struct crd_parsed_csv {
 
     u_int32_t addr;
     u_int32_t len;
-    char      enable_addr[100];
+    char enable_addr[100];
 
 } crd_parsed_csv_t;
 
@@ -91,72 +91,73 @@ struct crd_ctxt {
     mfile     *mf;
     u_int32_t dev_type;
     u_int32_t number_of_dwords;
-    int       is_full;
-    int       cause_addr;
-    int       cause_off;
-    char      csv_path[CRD_CSV_PATH_SIZE];
+    int is_full;
+    int cause_addr;
+    int cause_off;
+    char csv_path[CRD_CSV_PATH_SIZE];
     u_int32_t block_count;
-    crd_parsed_csv_t * blocks;
+    crd_parsed_csv_t *blocks;
 };
 
 static char crd_error[256];
 
 /*
-Store the csv file path at csv_file_path.
+   Store the csv file path at csv_file_path.
  */
-static int crd_get_csv_path(IN dm_dev_id_t dev_type, OUT char *csv_file_path, IN const char * db_path);
+static int crd_get_csv_path(IN dm_dev_id_t dev_type, OUT char *csv_file_path, IN const char *db_path);
 
 /*
-count number of dwords, and store all needed data from csv file at parsed_csv
+   count number of dwords, and store all needed data from csv file at parsed_csv
  */
-static int crd_count_double_word(IN  char *csv_file_path, OUT u_int32_t *number_of_dwords,
+static int crd_count_double_word(IN char *csv_file_path, OUT u_int32_t *number_of_dwords,
                                  OUT crd_parsed_csv_t blocks[], IN int is_full,
                                  IN u_int8_t read_single_dword);
 
 /*
-Fill addresses at dword_arr
+   Fill addresses at dword_arr
  */
-static int crd_fill_address(IN crd_ctxt_t *context, OUT crd_dword_t * dword_arr);
+static int crd_fill_address(IN crd_ctxt_t *context, OUT crd_dword_t *dword_arr);
 
 /*
-Read a line from csv file
+   Read a line from csv file
  */
 static int crd_read_line(IN FILE *fd, OUT char *tmp);
 
 /*
-Tokenize line for address, len, and enable_adder
+   Tokenize line for address, len, and enable_adder
  */
 
-static void crd_parse(IN  char *record, IN  char *delim, OUT char arr[][CRD_MAXFLDSIZE], OUT int *field_count);
+static void crd_parse(IN char *record, IN char *delim, OUT char arr[][CRD_MAXFLDSIZE], OUT int *field_count);
 
-static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char * db_path);
+static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char *db_path);
 
 static int crd_count_blocks(IN char *csv_file_path, OUT u_int32_t *block_count, u_int8_t read_single_dword);
 
 #if !defined(__WIN__) && !defined(MST_UL)
-static char *crd_trim(char *s);
+static char* crd_trim(char *s);
 
-static char *crd_rtrim(char *s);
+static char* crd_rtrim(char *s);
 
-static char *crd_ltrim(char *s);
-#endif 
+static char* crd_ltrim(char *s);
+#endif
 
 
 #if defined(__WIN__)
-    static int crd_replace(INOUT char *st, IN char *orig, IN char *repl);
+static int crd_replace(INOUT char *st, IN char *orig, IN char *repl);
 
-    static int crd_get_exec_name_from_path(IN char *str, OUT char *exec_name);
+static int crd_get_exec_name_from_path(IN char *str, OUT char *exec_name);
 #endif
 
-int crd_init(OUT crd_ctxt_t **context, IN mfile *mf, IN int is_full, IN int cause_addr, IN int cause_off, IN const char * db_path) {
+int crd_init(OUT crd_ctxt_t **context, IN mfile *mf, IN int is_full, IN int cause_addr, IN int cause_off, IN const char *db_path)
+{
 
     dm_dev_id_t dev_type = DeviceUnknown;
-    u_int32_t   dev_id = 0;
-    u_int32_t   chip_rev = 0;
-    u_int32_t   number_of_dwords = 0;
-    u_int32_t   block_count = 0;
-    u_int8_t    read_single_dword = 0;
-    char        csv_file_path [CRD_CSV_PATH_SIZE] = {0x0};
+    u_int32_t dev_id = 0;
+    u_int32_t chip_rev = 0;
+    u_int32_t number_of_dwords = 0;
+    u_int32_t block_count = 0;
+    u_int8_t read_single_dword = 0;
+    char csv_file_path [CRD_CSV_PATH_SIZE] = {0x0};
 
 
     int rc = CRD_OK;
@@ -198,7 +199,7 @@ int crd_init(OUT crd_ctxt_t **context, IN mfile *mf, IN int is_full, IN int caus
     }
 
     CRD_DEBUG("Block count : %d\n", block_count);
-    (*context)->blocks = (crd_parsed_csv_t *) malloc(sizeof(crd_parsed_csv_t) * block_count);
+    (*context)->blocks = (crd_parsed_csv_t*) malloc(sizeof(crd_parsed_csv_t) * block_count);
     if ((*context)->blocks == NULL) {
         CRD_DEBUG("Failed to allocate memmory for csv blocks\n");
         free(*context);
@@ -211,6 +212,8 @@ int crd_init(OUT crd_ctxt_t **context, IN mfile *mf, IN int is_full, IN int caus
         goto Cleanup;
     }
 
+    mset_addr_space(mf, AS_ND_CRSPACE);
+
     CRD_DEBUG("Number of found dwords are : %d \n", number_of_dwords);
     (*context)->mf               = mf;
     (*context)->dev_type         = dev_type;
@@ -222,13 +225,14 @@ int crd_init(OUT crd_ctxt_t **context, IN mfile *mf, IN int is_full, IN int caus
     strcpy((*context)->csv_path, csv_file_path);
     return rc;
 
-    Cleanup:
+Cleanup:
     crd_free(*context);
     return rc;
 }
 
 
-int crd_get_addr_list(IN crd_ctxt_t *context, OUT crd_dword_t* dword_arr) {
+int crd_get_addr_list(IN crd_ctxt_t *context, OUT crd_dword_t *dword_arr)
+{
 
     int rc;
 
@@ -243,7 +247,7 @@ int crd_get_addr_list(IN crd_ctxt_t *context, OUT crd_dword_t* dword_arr) {
     return CRD_OK;
 }
 
-int crd_dump_data(IN crd_ctxt_t *context, OUT crd_dword_t* dword_arr, IN crd_callback_t func)
+int crd_dump_data(IN crd_ctxt_t *context, OUT crd_dword_t *dword_arr, IN crd_callback_t func)
 {
     u_int32_t i = 0;
     u_int32_t j = 0;
@@ -262,25 +266,25 @@ int crd_dump_data(IN crd_ctxt_t *context, OUT crd_dword_t* dword_arr, IN crd_cal
         return CRD_INVALID_PARM;
     }
 
-    for(i = 0; i< context->block_count; i++) {
-        if(!context->is_full && strcmp(context->blocks[i].enable_addr, CRD_EMPTY)) {
+    for (i = 0; i < context->block_count; i++) {
+        if (!context->is_full && strcmp(context->blocks[i].enable_addr, CRD_EMPTY)) {
             continue;
         }
 
-        data = (char*) malloc (context->blocks[i].len * sizeof(u_int32_t));
+        data = (char*) malloc(context->blocks[i].len * sizeof(u_int32_t));
         if (data == NULL) {
             return CRD_MEM_ALLOCATION_ERR;
         }
         memset(data, 0, context->blocks[i].len * sizeof(u_int32_t));
 
-        rc = mread4_block (context->mf, context->blocks[i].addr, (u_int32_t *)data, context->blocks[i].len * sizeof(u_int32_t));
+        rc = mread4_block(context->mf, context->blocks[i].addr, (u_int32_t*)data, context->blocks[i].len * sizeof(u_int32_t));
         if (context->blocks[i].len * sizeof(u_int32_t) != rc) {
             sprintf(crd_error, "Cr read (0x%08x) failed: %s(%d)", context->blocks[i].addr, strerror(errno), (u_int32_t)errno);
             free(data);
             return CRD_CR_READ_ERR;
         }
 
-        for (j = 0; j< context->blocks[i].len; j++) {
+        for (j = 0; j < context->blocks[i].len; j++) {
             if ((u_int32_t)total >= context->number_of_dwords) { // dummy check tadah!
                 CRD_DEBUG("value exceeded, something wrong in calculation!");
                 free(data);
@@ -304,7 +308,7 @@ int crd_dump_data(IN crd_ctxt_t *context, OUT crd_dword_t* dword_arr, IN crd_cal
                 }
             }
 
-            if(dword_arr != NULL) {
+            if (dword_arr != NULL) {
                 dword_arr[total].addr = addr;
                 dword_arr[total].data = ((u_int32_t*)data)[j];
             }
@@ -320,7 +324,8 @@ int crd_dump_data(IN crd_ctxt_t *context, OUT crd_dword_t* dword_arr, IN crd_cal
     return CRD_OK;
 }
 
-int crd_get_dword_num(IN crd_ctxt_t *context, OUT u_int32_t *arr_size) {
+int crd_get_dword_num(IN crd_ctxt_t *context, OUT u_int32_t *arr_size)
+{
 
     CRD_CHECK_NULL(context);
     *arr_size = context->number_of_dwords;
@@ -328,11 +333,12 @@ int crd_get_dword_num(IN crd_ctxt_t *context, OUT u_int32_t *arr_size) {
 }
 
 
-static int crd_get_csv_path(IN dm_dev_id_t dev_type, OUT char *csv_file_path, IN const char * db_path) {
+static int crd_get_csv_path(IN dm_dev_id_t dev_type, OUT char *csv_file_path, IN const char *db_path)
+{
 
     const int dev_name_len = 100;
     char dev_name[100] = {0};
-    int  rc;
+    int rc;
 
     strncpy(dev_name, dm_dev_type2str(dev_type), dev_name_len - 1);
 
@@ -348,15 +354,16 @@ static int crd_get_csv_path(IN dm_dev_id_t dev_type, OUT char *csv_file_path, IN
     return CRD_OK;
 }
 
-static void crd_parse(IN  char *record, IN  char *delim, OUT char arr[][CRD_MAXFLDSIZE],
-                      OUT int *field_count) {
+static void crd_parse(IN char *record, IN char *delim, OUT char arr[][CRD_MAXFLDSIZE],
+                      OUT int *field_count)
+{
 
     char *p = strtok(record, delim);
     int field = 0;
-    strcpy(arr[0],"\0");
-    strcpy(arr[1],"\0");
-    strcpy(arr[2],"\0");
-    while(p) {
+    strcpy(arr[0], "\0");
+    strcpy(arr[1], "\0");
+    strcpy(arr[2], "\0");
+    while (p) {
         strcpy(arr[field], p);
         field++;
         p = strtok(NULL, delim);
@@ -365,26 +372,27 @@ static void crd_parse(IN  char *record, IN  char *delim, OUT char arr[][CRD_MAXF
 }
 
 static int crd_count_blocks(IN char *csv_file_path,
-                            OUT u_int32_t *block_count, u_int8_t read_single_dword) {
+                            OUT u_int32_t *block_count, u_int8_t read_single_dword)
+{
 
     char tmp[1024] = {0x0};
-    char arr[CRD_MAXFLDS][CRD_MAXFLDSIZE] ;
+    char arr[CRD_MAXFLDS][CRD_MAXFLDSIZE];
     int field_count = 0;
     *block_count = 0;
 
     CRD_DEBUG("CSV file path : %s\n", csv_file_path);
-    FILE * fd = fopen(csv_file_path, "r");
+    FILE *fd = fopen(csv_file_path, "r");
     if (fd == NULL) {
         CRD_DEBUG("Failed to open csv file : '%s'\n", csv_file_path);
         sprintf(crd_error, "Failed to open csv file : '%s'", csv_file_path);
         return CRD_OPEN_FILE_ERROR;
     }
-    while(!feof(fd)) {
+    while (!feof(fd)) {
         if (crd_read_line(fd, tmp) == CRD_SKIP) {
             continue;
         }
         crd_parse(tmp, ",", arr, &field_count); /* whack record into fields */
-        if (field_count < 2 ) {
+        if (field_count < 2) {
             CRD_DEBUG("CSV File has bad format, line : %s\n", tmp);
             sprintf(crd_error, "CSV File has bad format, line : %s", tmp);
             fclose(fd);
@@ -402,7 +410,8 @@ static int crd_count_blocks(IN char *csv_file_path,
 
 static int crd_count_double_word(IN char *csv_file_path, OUT u_int32_t *number_of_dwords,
                                  OUT crd_parsed_csv_t blocks[], IN int is_full,
-                                 IN u_int8_t read_single_dword) {
+                                 IN u_int8_t read_single_dword)
+{
 
     int field_count       = 0;
     int block_count       = 0;
@@ -411,24 +420,24 @@ static int crd_count_double_word(IN char *csv_file_path, OUT u_int32_t *number_o
     u_int32_t i           = 0;
     char enable_addr[100] = {0};
     char tmp[1024]  = {0x0};
-    char arr[CRD_MAXFLDS][CRD_MAXFLDSIZE] ;
+    char arr[CRD_MAXFLDS][CRD_MAXFLDSIZE];
 
     *number_of_dwords = 0;
 
     CRD_DEBUG("CSV file path : %s\n", csv_file_path);
-    FILE * fd = fopen(csv_file_path, "r");
+    FILE *fd = fopen(csv_file_path, "r");
     if (fd == NULL) {
         CRD_DEBUG("Failed to open csv file : '%s'\n", csv_file_path);
         sprintf(crd_error, "Failed to open csv file : '%s'", csv_file_path);
         return CRD_OPEN_FILE_ERROR;
     }
 
-    while(!feof(fd)) {
+    while (!feof(fd)) {
         if (crd_read_line(fd, tmp) == CRD_SKIP) {
             continue;
         }
         crd_parse(tmp, ",", arr, &field_count); /* whack record into fields */
-        if (field_count < 2 ) {
+        if (field_count < 2) {
             CRD_DEBUG("CSV File has bad format, line : %s\n", tmp);
             sprintf(crd_error, "CSV File has bad format, line : %s", tmp);
             fclose(fd);
@@ -441,11 +450,10 @@ static int crd_count_double_word(IN char *csv_file_path, OUT u_int32_t *number_o
             blocks[block_count].len  = len;
             if (field_count > 2) {
                 strcpy(blocks[block_count].enable_addr, arr[2]);
-                if(is_full || (!is_full && !strcmp(blocks[block_count].enable_addr, CRD_EMPTY))) {
+                if (is_full || (!is_full && !strcmp(blocks[block_count].enable_addr, CRD_EMPTY))) {
                     *number_of_dwords += len;
                 }
-            }
-            else {
+            } else   {
                 strcpy(blocks[block_count].enable_addr, CRD_EMPTY);
                 *number_of_dwords += len;
             }
@@ -456,7 +464,7 @@ static int crd_count_double_word(IN char *csv_file_path, OUT u_int32_t *number_o
             } else {
                 strcpy(enable_addr, CRD_EMPTY);
             }
-            if(is_full || (!is_full && !strcmp(enable_addr, CRD_EMPTY))) {
+            if (is_full || (!is_full && !strcmp(enable_addr, CRD_EMPTY))) {
                 *number_of_dwords += len;
             }
             for (i = 0; i < len; i++) {
@@ -472,16 +480,17 @@ static int crd_count_double_word(IN char *csv_file_path, OUT u_int32_t *number_o
     return CRD_OK;
 }
 
-static int crd_fill_address(IN crd_ctxt_t *context, OUT crd_dword_t * dword_arr) {
+static int crd_fill_address(IN crd_ctxt_t *context, OUT crd_dword_t *dword_arr)
+{
     u_int32_t i = 0;
     u_int32_t j = 0;
     int total = 0;
 
-    for(i = 0; i< context->block_count; i++) {
-        for(j = 0; j< context->blocks[i].len; j++) {
+    for (i = 0; i < context->block_count; i++) {
+        for (j = 0; j < context->blocks[i].len; j++) {
 
             //CRD_UNKOWN, CRD_EMPTY
-            if(!context->is_full && strcmp(context->blocks[i].enable_addr, CRD_EMPTY)) {
+            if (!context->is_full && strcmp(context->blocks[i].enable_addr, CRD_EMPTY)) {
                 break;
             }
             if ((u_int32_t)total >= context->number_of_dwords) {
@@ -495,7 +504,8 @@ static int crd_fill_address(IN crd_ctxt_t *context, OUT crd_dword_t * dword_arr)
     return CRD_OK;
 }
 
-static int crd_read_line(IN FILE *fd, OUT char *tmp) {
+static int crd_read_line(IN FILE *fd, OUT char *tmp)
+{
 
     int i = 0;
     int j = 0;
@@ -503,27 +513,22 @@ static int crd_read_line(IN FILE *fd, OUT char *tmp) {
         if (!feof(fd)) {
             int c = fgetc(fd);
             if (c == '#') {
-                if (!fgets (tmp, 300, fd)) { // Avoid warning
+                if (!fgets(tmp, 300, fd)) {  // Avoid warning
                 }
                 tmp[0] = 0;
                 continue;
-            }
-            else if (c == '\r') {
+            } else if (c == '\r')   {
                 break;
-            }
-            else if (c == '\n') {
+            } else if (c == '\n')   {
                 break;
-            }
-            else if (c == ' ') {
+            } else if (c == ' ')   {
                 continue;
-            }
-            else {
+            } else   {
                 j++;
                 tmp[i] = c;
                 i++;
             }
-        }
-        else {
+        } else   {
             return CRD_SKIP;
         }
     }
@@ -536,64 +541,77 @@ static int crd_read_line(IN FILE *fd, OUT char *tmp) {
 
 #if defined(__WIN__)
 
-static int crd_replace(INOUT char *st, IN char *orig, IN char *repl) {
-  char buffer[CRD_CSV_PATH_SIZE] = {0x0};
+static int crd_replace(INOUT char *st, IN char *orig, IN char *repl)
+{
+    char buffer[CRD_CSV_PATH_SIZE] = {0x0};
     char *ch;
 
     if (!(ch = strstr(st, orig))) {
         return CRD_OK;
     }
-    strncpy(buffer, st, ch-st);
-    buffer[ch-st] = 0;
-    sprintf(buffer+(ch-st), "%s%s", repl, ch+strlen(orig));
+    strncpy(buffer, st, ch - st);
+    buffer[ch - st] = 0;
+    sprintf(buffer + (ch - st), "%s%s", repl, ch + strlen(orig));
     strcpy(st, buffer);
 
     return CRD_OK;
 }
 
-static int crd_get_exec_name_from_path(IN char *str, OUT char *exec_name) {
-    char tmp_str[strlen(str) + 1];
-    char * pch;
+static int crd_get_exec_name_from_path(IN char *str, OUT char *exec_name)
+{
+    char *tmp_str = malloc(sizeof(char) * (strlen(str) + 1));
+    if (tmp_str == NULL) {
+        CRD_DEBUG("Failed to allocate memmory\n");
+        return CRD_MEM_ALLOCATION_ERR;
+    }
+    char *pch;
     strcpy(tmp_str, str);
-    pch = strtok (tmp_str,"\\");
+    pch = strtok(tmp_str, "\\");
     while (pch != NULL) {
         strcpy(exec_name, pch);
-        pch = strtok (NULL, "\\");
+        pch = strtok(NULL, "\\");
     }
+    free(tmp_str);
     return CRD_OK;
 }
-#endif 
+#endif
 
 
 #if !defined(__WIN__) && !defined(MST_UL)
-static char *crd_ltrim(char *s) {
-    while(isspace(*s)){
+static char* crd_ltrim(char *s)
+{
+    while (isspace(*s)) {
         s++;
     }
     return s;
 }
 
-static char *crd_rtrim(char *s) {
-    char* back;
+static char* crd_rtrim(char *s)
+{
+    char *back;
     int len = strlen(s);
 
-    if(len == 0) {
+    if (len == 0) {
         return(s);
     }
     back = s + len;
-    while(isspace(*--back));
-    *(back+1) = '\0';
+    while (isspace(*--back)) {
+        ;
+    }
+    *(back + 1) = '\0';
     return s;
-	}
+}
 
-static char *crd_trim(char *s){
+static char* crd_trim(char *s)
+{
     return crd_rtrim(crd_ltrim(s));
 }
-#endif 
+#endif
 
-static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char * db_path) {
+static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char *db_path)
+{
 
-    int       found  = 0;
+    int found  = 0;
 #ifdef __WIN__
     char exec_name[CRD_CSV_PATH_SIZE];
     (void)db_path;
@@ -608,15 +626,14 @@ static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char * db_pa
     found = 1;
 
 #else
-    char      conf_path[256] = ROOT_PATH;
-    char      data_path[CRD_CSV_PATH_SIZE] = {0x0};
-    char      prefix[CRD_CSV_PATH_SIZE] = {0x0};
-    char      * tmp_value = NULL;
-    char      line[CRD_MAXLINESIZE] = {0};
+    char conf_path[256] = ROOT_PATH;
+    char data_path[CRD_CSV_PATH_SIZE] = {0x0};
+    char prefix[CRD_CSV_PATH_SIZE] = {0x0};
+    char      *tmp_value = NULL;
+    char line[CRD_MAXLINESIZE] = {0};
     FILE      *fd;
 
-    if(db_path != NULL && *db_path != '\0')
-    {
+    if (db_path != NULL && *db_path != '\0') {
         strncpy(csv_file_path, db_path, CRD_CSV_PATH_SIZE - 1);
         return CRD_OK;
     }
@@ -629,14 +646,14 @@ static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char * db_pa
     }
 
     while ((fgets(line, CRD_MAXLINESIZE, fd))) {
-        if(strstr(line, "mstdump_dbs") != NULL) {
+        if (strstr(line, "mstdump_dbs") != NULL) {
             tmp_value = strtok(line, "=");
             if (tmp_value != NULL) {
                 tmp_value = strtok(NULL, "=");
                 crd_trim(tmp_value);
                 strncpy(data_path, tmp_value, CRD_CSV_PATH_SIZE - 1);
             }
-        } else if(strstr(line, "mft_prefix_location") != NULL) {
+        } else if (strstr(line, "mft_prefix_location") != NULL) {
             tmp_value = strtok(line, "=");
             if (tmp_value != NULL) {
                 tmp_value = strtok(NULL, "=");
@@ -660,39 +677,52 @@ static int crd_update_csv_path(IN OUT char *csv_file_path, IN const char * db_pa
     return CRD_OK;
 }
 
-void crd_free(IN crd_ctxt_t *context) {
+void crd_free(IN crd_ctxt_t *context)
+{
     free(context->blocks);
     free(context);
 }
 
-
-const char* crd_err_str(int rc) {
+const char* crd_err_str(int rc)
+{
     switch (rc) {
-        case CRD_OK:
-            return "Ok";
-        case CRD_MEM_ALLOCATION_ERR:
-            return "Memory allocation error";
-        case CRD_CR_READ_ERR:
-            return crd_error;
-        case CRD_INVALID_PARM:
-            return "Invalid parameter";
-        case CRD_UNKOWN_DEVICE:
-            return "Unknown/Unsupported device";
-        case CRD_CSV_BAD_FORMAT:
-            return crd_error;
-        case CRD_CONF_BAD_FORMAT:
-            return "Conf file has no valid mstdumb_db path.";
-        case CRD_OPEN_FILE_ERROR:
-            return crd_error;
-        case CRD_SKIP:
-            return "Skip";
-        case CRD_NOT_SUPPORTED:
-            return "Not supported";
-        case CRD_EXCEED_VALUE:
-            return "Value exceed";
-        case CRD_CAUSE_BIT:
-            return crd_error;
-        default:
-            return "Unknown error";
+    case CRD_OK:
+        return "Ok";
+
+    case CRD_MEM_ALLOCATION_ERR:
+        return "Memory allocation error";
+
+    case CRD_CR_READ_ERR:
+        return crd_error;
+
+    case CRD_INVALID_PARM:
+        return "Invalid parameter";
+
+    case CRD_UNKOWN_DEVICE:
+        return "Unknown/Unsupported device";
+
+    case CRD_CSV_BAD_FORMAT:
+        return crd_error;
+
+    case CRD_CONF_BAD_FORMAT:
+        return "Conf file has no valid mstdumb_db path.";
+
+    case CRD_OPEN_FILE_ERROR:
+        return crd_error;
+
+    case CRD_SKIP:
+        return "Skip";
+
+    case CRD_NOT_SUPPORTED:
+        return "Not supported";
+
+    case CRD_EXCEED_VALUE:
+        return "Value exceed";
+
+    case CRD_CAUSE_BIT:
+        return crd_error;
+
+    default:
+        return "Unknown error";
     }
 }
