@@ -28,8 +28,8 @@
  * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
+ *
  */
-
 /*
  *
  *  mtcr_ib.h - Mellanox Software tools (mst) IB related driver definitions
@@ -39,7 +39,7 @@
 #ifndef _MTCR_IB_H
 #define _MTCR_IB_H
 
- #include <mtcr.h>
+#include <mtcr.h>
 
 int mib_open(const char *name, mfile *mf, int mad_init);
 int mib_close(mfile *mf);
@@ -54,7 +54,10 @@ int mib_swreset(mfile *mf);
 int mib_get_chunk_size(mfile *mf);
 int mib_acces_reg_mad(mfile *mf, u_int8_t *data);
 
-int mib_smp_set(mfile* mf, u_int8_t* data, u_int16_t attr_id, u_int32_t attr_mod);
-int mib_smp_get(mfile* mf, u_int8_t* data, u_int16_t attr_id, u_int32_t attr_mod);
+int mib_smp_set(mfile *mf, u_int8_t *data, u_int16_t attr_id, u_int32_t attr_mod);
+int mib_smp_get(mfile *mf, u_int8_t *data, u_int16_t attr_id, u_int32_t attr_mod);
+int mib_get_gmp(mfile *mf, unsigned attr_id, unsigned mod, u_int32_t *vsmad_data, size_t vsmad_data_len);
+int mib_supports_reg_access_gmp(mfile *mf, maccess_reg_method_t reg_method);
+int mib_send_gmp_access_reg_mad(mfile *mf, u_int32_t *data, u_int32_t reg_size, u_int32_t reg_id, maccess_reg_method_t reg_method);
 
 #endif
